/*
Theme Name: Archi
Theme URI: http://archiwp.com/
Author: OceanThemes
Author URI: http://oceanthemes.net/
Description: Archi specially made for Interior Design services, Dining Room, Exterior Design, Kitchen Design, Living Room Design, Master Bedroom Design, Residential Design, Furniture Design, Office Design, Commercial Design, Hospital Design, Cottage, Architecture, contractor, construction, building, Construction & Business etc… . Archi help you to build beauty and modern website in no time. Archi has beauty design and bunch of features to make your website stand out of crowd.
Version: 4.4.19
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Tags: two-columns, three-columns, left-sidebar, right-sidebar, custom-background, custom-header, custom-menu, editor-style, featured-images, flexible-header, full-width-template, microformats, post-formats, rtl-language-support, sticky-post, theme-options, translation-ready
Text Domain: archi
Domain Path: /languages

This theme, like WordPress, is licensed under the GPL.
Use it to make something cool, have fun, and share what you've learned with others.
*/

/*------------------------------------------------------------------
[Table of contents]
* body
* header
    * subheader
* navigation
* content
* section
* footer
* sidebar
* blog
* products
* contact
* coming soon page
* elements
    * address
    * border
    * breadcrumb
    * button
    * columns
    * counter
    * divider
    * dropcap
    * heading
    * icon font
    * map
    * package
    * page heading
    * pagination
    * pricing
    * progress bar
    * social icons
    * spacer
    * tabs
    * team
    * testimonial
* media query
-------------------------------------------------------------------*/


/* -------------------------------------------------- */
/* body */
/* ================================================== */
html{background:#000000;}
body {
    font-family: "Open Sans",Arial, Helvetica, sans-serif;
    font-size: 13px;
    font-weight:500;
    color: #ddd;
    line-height: 1.8em;
    padding: 0;
    background:#606060;    
}
#wrapper{overflow:hidden;}
h1, h2, h3, h4, h5, h6, .de_count h3, .typing-wrap, .de_tab.tab_steps .de_nav li span, h3 b,
ul.countdown li span, ul.countdown li p, .teaser-text, .text-slider, .big-white, 
.ultra-big-white, .big-text h2, .de-navbar-left header .mainmenu > li {
    font-family:"Dosis", Arial, Helvetica, sans-serif;
}
h1.title strong, h1.title-3 strong{font-family:"Allura";}

/**** Start Reset CSS For WordPress ****/
.alignnone {max-width: 100%;height: auto;}
.wp-caption.alignnone img {max-width: 100%;height: auto;}
.align-center {
  width: 100%;
  text-align: center;
}
.align-right {text-align:right;}
.align-left {text-align: left;}
.fleft {float: left;}
.fright {float: right;}
a, a:hover, a:active, a:focus {
     outline: 0;
}
table,
th,
td {
  border: 1px solid rgba(0, 0, 0, 0.1);
}

table {
  border-collapse: separate;
  border-spacing: 0;
  border-width: 1px 0 0 1px;
  margin-bottom: 24px;
  width: 100%;
}

caption,
th,
td {
  font-weight: normal;
  text-align: left;
  padding: 10px 20px;
}

th {
  border-width: 0 1px 1px 0;
  font-weight: bold;
}

td {
  border-width: 0 1px 1px 0;
}
dl {
  margin-bottom: 24px;
}

dt {
  font-weight: bold;
}

dd {
  margin-bottom: 24px;
}
/* Alignment */

.alignleft {
  float: left;
}

.alignright {
  float: right;
}

.aligncenter {
  display: block;
  margin-left: auto;
  margin-right: auto;
  text-align: center;
}

blockquote.alignleft,
figure.wp-caption.alignleft,
img.alignleft {
  margin: 7px 24px 7px 0;
}

.wp-caption.alignleft {
  margin: 7px 14px 7px 0;
  text-align: left;
}

figure.wp-block-embed.alignleft{
    margin-right: 24px;
}
.wp-block-embed {
    margin: 0px;
    margin-bottom: 30px;
    clear: both;
}


blockquote.alignright,
figure.wp-caption.alignright,
img.alignright {
  margin: 7px 0 7px 24px;
}
blockquote cite, p cite {display: inline-block;margin: 10px 0px;font-style: italic;color: #101010;font-weight: bold;}
.wp-caption.alignright {
  margin: 7px 0 7px 14px;
  text-align: right;
}

blockquote.aligncenter,
img.aligncenter,
.wp-caption.aligncenter {
  margin-top: 7px;
  margin-bottom: 7px;
}
.wp-caption {
  margin-bottom: 24px;
  max-width: 100%;
  color: #767676;
}
.gallery-caption {}
.bypostauthor{}
.wp-caption-text {
  -webkit-box-sizing: border-box;
  -moz-box-sizing:    border-box;
  box-sizing:         border-box;
  font-size: 12px;
  font-style: italic;
  line-height: 1.5;
  margin: 9px 0;
}

div.wp-caption .wp-caption-text {
  padding-right: 10px;
}

div.wp-caption.alignright img[class*="wp-image-"],
div.wp-caption.alignright .wp-caption-text {
  padding-left: 10px;
  padding-right: 0;
}

.wp-smiley {
  border: 0;
  margin-bottom: 0;
  margin-top: 0;
  padding: 0;
}
pre, code {
    background-color: #F9F9F9;
    border-color: rgba(180,180,180,1);
    border-style: solid;
    border-width: 0px 0px 0px 4px;
    display: block;    
    font-weight: 300;
    font-size: 14px;
    padding: 10px;
    margin-top:20px;
    margin-left:20px;
    margin-right:20px;
    overflow: auto;
}
.textwidget select {
  max-width: 100%;
}
.textwidget img {height: auto;}
/* Text meant only for screen readers. */
.screen-reader-text {
    clip: rect(1px, 1px, 1px, 1px);
    position: absolute ;
    height: 1px;
    width: 1px;
    overflow: hidden;
}

.screen-reader-text:focus {
    background-color: #f1f1f1;
    border-radius: 3px;
    box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
    clip: auto ;
    color: #21759b;
    display: block;
    font-size: 14px;
    font-size: 0.875rem;
    font-weight: bold;
    height: auto;
    left: 5px;
    line-height: normal;
    padding: 15px 23px 14px;
    text-decoration: none;
    top: 5px;
    width: auto;
    z-index: 100000; /* Above WP toolbar. */
}
img{height: auto;}
/**** End Reset CSS For WordPress ****/

/* ================================================== */
/*  header  */ 
/* ================================================== */
    header {
        width: 100%;
        height: 80px;
        position: fixed;
        top: 0;
        left: 0;
        z-index: 1043;
        -webkit-transition: height 0.3s;
        -moz-transition: height 0.3s;
        -ms-transition: height 0.3s;
        -o-transition: height 0.3s;
        transition: height 0.3s;
        background:#18191b;
        border-bottom:solid 1px rgba(0,0,0,0.0);
    }
    
    header .info{        
        color:#fff;
        text-align:right;
        padding:10px 0 10px 0;
        width:100%;
        z-index:100;
        border-bottom:solid 1px rgba(255,255,255,.2);
    }    
    header .info ul.info-list {
        margin: 0;
        padding: 0;
        text-align: left;
    }   
    header .info ul.info-list li {
        display: inline-block;
        margin-right: 25px;
        font-size: 12px;
        letter-spacing: 1px;
    }
    header .info ul.info-list li i {
        color: #fab207;
        display: inline-block;
        float: none;
        font-size: 14px;
        margin-bottom: 0;
        margin-right: 8px;
    }
    header .info ul.info-list li span {
        font-weight: bold;
    }
    header .info ul.social-list {
        margin: 0;
        padding: 0;
        text-align: right;
        float: right;
    }
    header .info ul.social-list li {
        display: inline-block;
        margin-left: 15px;
        float: left;
    }
    header .info ul.social-list li i{
        color: #fff;
        display: inline-block;
        float: none;
        font-size: 14px;
        margin: 0px 0px 0px 0px;
        -o-transition:.5s;
        -ms-transition:.5s;
        -moz-transition:.5s;
        -webkit-transition:.5s;
        transition:.5s;
    }    

    .topbar-login {
        list-style: none;
        float: right;
        padding-left: 20px;
    }
    .topbar-login li i {
        float: none;
        margin-right: 5px;
    }

    header.header-light .info,
    header.header-light .topbar-login li a,
    header.header-light .info ul.social-list li i{
        color:#333;
    }
    header.transparent.header-light .info,
    header.transparent.header-light .info ul.social-list li i {
        color:#fff;
    }

    header.header-bg {
        background:rgba(0,0,0,0.5);
    }
    
    header.transparent {
        background:rgba(0,0,0,0.0);
    }

    header.autoshow {
        top:-80px;
    }
    
    header.autoshow.scrollOn, header.autoshow.scrollOff{
        -o-transition:.5s;
        -ms-transition:.5s;
        -moz-transition:.5s;
        -webkit-transition:.5s;
        transition:.5s;
        outline: none;  
    }    
    header.autoshow.scrollOn {
        top:0;
    }    
    header.autoshow.scrollOff {
        top:-83px;
    }    
    header div#logo {
        height: 80px;
        line-height: 80px;
        float: left;               
        -webkit-transition: all 0.3s;
        -moz-transition: all 0.3s;
        -ms-transition: all 0.3s;
        -o-transition: all 0.3s;
        transition: all 0.3s; 
    }
    header div#logo a{display: inline-block;}
    header div#logo a img{
        max-width: 340px;
        max-height: 80px;
        -webkit-transition: all 0.3s;
        -moz-transition: all 0.3s;
        -ms-transition: all 0.3s;
        -o-transition: all 0.3s;
        transition: all 0.3s; 
    }
    header.smaller div#logo a img{
        max-width: 250px;
        max-height: 60px;
    }

    header div#logo .logo-2, header div#logo .logo-scroll{
        display:none;
    }
    header.smaller div#logo .logo-static {display: none;}
    header.smaller div#logo .logo-scroll {display: inline-block;}

    header nav {
        float:right;
    }
    header nav a {
        -webkit-transition: all 0.3s;
        -moz-transition: all 0.3s;
        -ms-transition: all 0.3s;
        -o-transition: all 0.3s;
        transition: all 0.3s; 
    }
    header nav a:hover {
        color: #555; 
    }
    
    header.smaller #mainmenu li li a{
        padding: 2px 15px;
    }
    header.smaller:not(.header-bottom) #mainmenu ul{
        top:70px;
    }
	header.smaller:not(.header-bottom) #mainmenu ul ul{
        top:0px;
    }
    header.smaller:not(.header-bottom):not(.side-header) {
        height: 70px;
        background:#18191b;
        border-bottom: solid 1px #333;
    }
    ul li a span.caret{
        display: none;
    }
    header.smaller div#logo {
        max-width: 300px;
        height:70px;
        line-height: 70px;
    }  
    header.fixed #mainmenu a{
        padding: 18px 20px 18px 20px ;    
    }
    header.fixed {
        height: 70px;
        background:rgba(255,255,255,0.90);
        border-bottom:solid 1px #ddd; 
    }
    header.fixed div#logo {
        width: 150px;
        height:30px;
        line-height: 65px;
        font-size: 30px;
    }
    header.fixed div#logo img{
        width:auto;
        height:30px;
        line-height: 75px;
        font-size: 30px;
    }
    header.fixed div#logo img.logo-1{
        display:none;
    }
    header.fixed div#logo img.logo-2{
        display:inline-block;
    }
    .center{
        text-align: center;
    }
    header.de_header_2{
        height:125px;   
    }
    
    header.de_header_2.smaller {
        height:70px;
    }
    header.de_header_2.smaller .info{
        position:absolute;
        opacity:0;
        z-index:-1;
    }
    header.header-light{
        background:#fff;
    }
    header.header-light.transparent{
        background:none;
    }
    header.smaller:not(.header-bottom).header-light{
        background:#fff;
        border-bottom-color:#eee;
    }
	header.smaller.header-bottom div#logo, .header-bottom div#logo {
		height: 80px;
		line-height: 80px;
		max-height: 80px;
	}
	header.header-bottom #mainmenu > li > a {padding: 22px 0 23px 20px;line-height: 35px;}
    .logged-in.admin-bar header {top:32px;}
    /*header bottom*/

    /* subheader */
    #subheader{
        padding-bottom:70px;
        padding-top: 90px;
        background:#222;
    }
    .has-topbar #subheader{padding-top: 130px;}
    .header-no-sticky-subheader #subheader{padding-top: 0px;}
    #subheader .title-wrap{
        float:left;
    }
    #subheader h1 {
        margin-top:80px;
        color:#eceff3;        
        font-size: 32px;
        letter-spacing: 5px;
        padding-right: 40px;
        text-transform:uppercase;
        text-align: left;
    }    
    #subheader h4{
        color:#fff;
        margin-top:10px;
        font-weight:500;
        text-transform:none;
        text-align: left;
    }
    #subheader span {
        letter-spacing:2px;
        display: inline-block;
        font-size: 15px;
        margin-top:88px;
        color:#fff;
    }
    #subheader .crumb{
        font-size:10px;
        letter-spacing:3px;
        margin-top: 85px;
        color:#fff;
        text-transform:uppercase;
    }
    #subheader .crumb li:after {
        content: '/';
        display: inline-block;
        margin-left: 5px;
    }
    #subheader .crumb li:last-child:after{
        content: '';
    }
    .no-subpage {height: 80px;}
    .has-topbar .no-subpage {
        height:125px;
    }
    .no-subheader header{
        border-bottom: 1px solid #333;
        box-shadow: 0 0 5px rgba(0, 0, 0, 0.1);
    }
    .home.no-subheader header{
        border-bottom: 0px solid #333;
        box-shadow: 0 0 0px rgba(0, 0, 0, 0.1);
    }    
    .moving-home {          
        background-attachment: scroll;
        background-repeat: repeat;  
        position: absolute;
        background-size:cover;
        top: 0; 
        left: 0; 
        bottom: 0;
        z-index: 1;
        width:100%; 
    }

/* ================================================== */
/* navigation */
/* ================================================== */
    #mainmenu {
        font-family: 'Raleway', Arial, Helvetica, sans-serif;
        float: right;
        font-size:11px;
        font-weight:400;
        letter-spacing:3px;
        text-transform:uppercase;
    	margin-bottom: 0px;
    }          
    #mainmenu li {
        margin: 0px 0px;
        padding: 0px 0px;
        float: left;
        display: inline;
        list-style: none;
        position: relative;
    }        
    #mainmenu a {
        display: block;
        padding: 25px 0 22px 20px;
        line-height: 33px;
        text-decoration: none;
        color:#fff;
        text-align:center;
        outline:none;
    }
    header.smaller:not(.header-bottom) #mainmenu > li > a{
        padding-top: 18px;
        padding-bottom: 17px;
    }
    #mainmenu ul li a b{
        font-weight: normal;
    }  
    h1 b{
        font-weight: normal;
    }  
    #mainmenu li a:after {
        position:relative; 
        font-family:"FontAwesome"; 
        content:"\f111"; 
        font-size:6px; 
        margin-left:20px; 
        margin-top:0px; 
        color:#FAB702;
        float:right;
    }
    #mainmenu li:last-child a:after{display:none;}
    #mainmenu.no-separator li a:after{
        content:"";
        font-size:0px;
    }   
    #mainmenu.line-separator li a:after{
        content:"/";
        font-size:14px;
    }   
    #mainmenu.circle-separator li a:after{
        content:"\f10c";
        font-size:9px;
    }   
    #mainmenu.strip-separator li a:after{
        content:"\f068";
        font-size:9px;
    }   
    #mainmenu.plus-separator li a:after{
        content:"\f067";
        font-size:11px;
    }   
    #mainmenu.square-separator li a:after{
        content:"\f096";
        font-size:11px;
    }       
    #mainmenu li li {
        font-size: 10px;
        font-weight: normal; 
        border-bottom: solid 1px #333;
    }
    #mainmenu li li:last-child {
        border-bottom: none;
    }
    #mainmenu li li a {
        padding: 2px 15px 2px 15px;
        background: #222327;
        border-top: none;
        color: #ccc;
        border-left:none;
        text-align:left;
    	line-height:35px;
    }
    #mainmenu li li a:after {
        content:none !important;
    }
    #mainmenu li li li a {
        padding: 2px 15px 2px 15px;
        background: #222327;
    }
    #mainmenu li li a:hover {
        color:#111;
        background: #1a8b49;
    }
    #mainmenu ul {
        float: right;
        margin: 0px 0px;
        padding: 0px 0px;
        height: 30px;
    } 
    #mainmenu > li > ul {
        width: 220px;
        height: auto;
        position: absolute;
        top: 140%;
        left: 0%;
        z-index: 100;
        visibility: hidden;
        opacity: 0;
        transition: all 400ms ease;
    }       
    #mainmenu > li:hover > ul {
        color: #1a8b49;
        opacity: 1;
        visibility: visible;
        top: 100%;
    }
    #mainmenu li li {
        display: block;
        float: none;
    } 
    #mainmenu ul ul{
      position:absolute;
      left:110%;
      top:0px;
      width:220px;
      padding:0px;
      z-index:100;      
      visibility:hidden;
      opacity:0;
      transition:all 500ms ease;
    }
    #mainmenu ul li:hover > ul {
      left: 100%;
      opacity: 1;
      visibility: visible;
    }
    .dropdown-menu > li > a {white-space: normal;}
    header.header-light #mainmenu > li > a,
    header.transparent.smaller.header-light #mainmenu > li > a{
        color:#333;
    }

    /* menu toggle for mobile */
    #menu-btn{
        display:none;
        float:right;
        margin-top:8px;
        width:36px;
        height:36px;
        background:#333;
        padding:6px;
        text-align:center;
        cursor:pointer;
        transition: all 0.5s;
		line-height: 1.8em;
    }    
    #menu-btn:before{
        font-family:FontAwesome;
        content: "\f0c9";
        font-size:24px;
        color:#eceff3;
        transition: all 0.5s;
    } 
    #menu-btn.active:before{content: "\f00d";}
    #menu-btn:hover{
        background:#fff;
    }
    #menu-btn:hover:before{
        color:#222;
    }

    /* ================================================== */
    /* content */
    /* ================================================== */
    #content {
        width:100%;
        background:#18191b;
        padding:90px 0 90px 0;
        z-index:100;
    }        

    /* ================================================== */
    /* section */
    /* ================================================== */    
    section{background:#18191b;}    
    .mfp-content section {background-color: transparent;}
    .section-fixed {
        position:fixed;
        width:100%;
        min-height:100%;
        height:auto;
    }
    .no-bg-fixed {
        background-attachment: scroll;
        background-position: center;
    }
    /* ================================================== */
    /* footer */
    /* ================================================== */
    footer {
        background: #111;
        color: #ccc;
        padding: 0px 0px 0px 0px;
    }
    footer .main-footer{
        padding: 80px 0px 0px 0px;
    }
    footer h3 {
        color:#fff;
        font-size: 20px;
    }
    
    footer a {
        color: #ccc;
    }
    
    footer a:visited {
        color: #ccc;
    }
    
    footer a:hover {
        color:#eceff3;
    }

    .subfooter{
        background:#0b0b0b;
        padding:30px 0 20px 0;
        border-top: 1px solid #0b0b0b; 
    }

    /* ================================================== */
    /* blog */
    /* ================================================== */
    .blog-list {
        margin: 0;
        padding: 0;
    }
    /* blog list */
    .blog-list article {        
        line-height: 1.7em;
        margin-bottom: 60px;
        margin-top:0;
        padding-bottom: 15px;
        border-bottom: solid 1px rgba(255,255,255,.1);
    }     
    .blog-list  li.single {        
        margin-bottom: 0px;
        margin-top:10px;
        padding-bottom: 0;
        border-bottom: 0;
    }
    .blog-list h3{
        margin-top:20px;
    }   
    .blog-list h3 a{
        color:#fff;
    }
    
    .blog-list .btn-more{
        padding:3px 25px 3px 25px;
        color:#111;
        text-transform:uppercase;
        text-decoration:none;
        font-weight:700;
        float:right;
        display: inline-block;
    }
    .blog-list .btn-more:hover{
        background:#fff;
    }
    
    .blog-list .post-text{
        padding-left:80px;
    }
    .blog-list .post-text.paddleft0 {padding-left: 0px;}
    .post-image iframe{
        margin-bottom: -6px;
    }
    .post-image{
        border-bottom:solid 4px;
    }
    .blog-list .blog-slider{
        margin-bottom:-60px;
    }
    .blog-list .date-box {
        width: 60px;
        float: left;
        text-align: center;
        text-shadow:none;
    }
    .blog-list .date-box .day, .blog-list .date-box .month {
        display: block;
        color:#fff;
        text-align:center;
        width:60px;
        z-index:100;
    }
    iframe{
        border:0;
        width: 100%;
    }
        
    .blog-list .date-box .month {
    font-size:14px;
    }
    
    .blog-list .date-box .day{
        color:#111;
        font-weight:600;
        font-size: 32px;
        padding-top:45px;
        padding-bottom:10px;
    }
    
    .blog-list .date-box .month {
        color:#fff;
        font-weight:600;
        letter-spacing:16px;
        padding:7px 0 7px 0;
        border-bottom:solid 4px #333;
        text-transform: uppercase;
    }
    
    .blog-snippet li{
        border-bottom:none ;
        margin-bottom:0;
    }
    .owl-carousel {padding: 0px;}
	.owl-carousel li {list-style: none;}
    .blog-carousel .item{
        width:100%;
        border-bottom: 0px solid #333;
        margin-bottom: 0px;
    }
    
    /* blog comment */
    #blog-comment {
        margin-top: 40px;
        margin-left: 80px;
    }
    
    #blog-comment h5 {
        margin-bottom: 10px;
    }
    
    #blog-comment ul, #blog-comment li {
        list-style: none;
        margin-left: -30px;
        padding-left: 0;
    }
    
    #blog-comment li {
        min-height: 70px;
        padding-bottom: 10px;
        margin-bottom: 10px;
        padding-bottom: 20px;
        border-bottom: solid 1px #eee;
    }
    
    #blog-comment li .avatar {
        position: absolute;
        margin-top: 5px;
    }
    
    #blog-comment .comment {
        margin-left: 85px;
    }
    
    #blog-comment li {
        min-height: 70px;
        font-size: 14px;
        line-height: 1.6em;
    }
    
    #blog-comment li li {
        margin-left: 55px;
        padding-bottom: 0px;
        margin-top: 20px;
        padding-top: 10px;
        border-top: solid 1px #eee;
        border-bottom: none;
    }
    
    #blog-comment li li .avatar {
        position: absolute;
    }
    .comment-info {
        margin-left: 85px;
        margin-bottom: 5px;
    }
    
    .comment-info .c_name {
        display: block;
        font-weight: 700;
        color: #555555;
    }
    
    .comment-info .c_reply {
        padding-left: 20px;
        margin-left: 20px;
        border-left: solid 1px #ddd;
        font-size: 12px;
    }
    
    .comment-info .c_date {
        font-size: 12px;
    }
    
    .blog-read h3 {
        color: #333;
        letter-spacing:normal;
        font-size:24px;
        text-transform:none;
    }
    .blog-list h3{
        color: #ffffff;
        text-transform: none;
        letter-spacing: 0;
        font-size: 24px;
    }

    /* blog comment form */
    #commentform label {
        display: block;
    }
    #commentform input {
        width: 290px;
    }
    #commentform input:focus {
        border: solid 1px #999;
        background: #fff;
    }
    #commentform textarea {
        width: 97%;
        padding: 5px;
        height: 150px;
        color:#333;
    }
    #commentform textarea:focus {
        border: solid 1px #999;
        background: #fff;
    }
    #commentform input.btn {
        width: auto;
    }
    
    .post-meta {
        margin: 0px 0 10px 0px;
        border: solid 1px #eee;
        border-left:none;
        font-size:11px;
        display:table;
        width:100%;
        table-layout: fixed;
    }
    .post-meta a{
        color:#888 ;
    }
    .post-meta span {
        display:table-cell;
        padding:10px 0 10px 0;
        text-align:center;
        border-left:solid 1px #eee;
    }
    .post-meta span i {
        float: none;
    }
    .post-image img {
        width:100%;
        margin-bottom: 0px;
    }
    .post-meta{
        border-color:#222;
    }
    .post-meta span{
        border-color:#222;
    }
    .post-info {
        margin: 40px 0 0px 80px;
        padding-bottom: 10px;
        border-bottom: solid 0px #ddd;
    }

        .post-info > span {
            margin-right: 15px;
        }

            .post-info span i {
                float: none;
            }
    
    .post-info a:hover{
        color:#fff;
    }

    .single-comment {
      list-style: none;
      padding-left: 0;
    }
    .single-comment .children{
        list-style: none;
        margin-top: 25px;
        margin-left:60px;
    }
    .single-comment li {
      min-height: 70px;
      
      margin-bottom: 10px;
      padding-bottom: 20px;
      border-bottom: solid 1px #ddd;
    }
    .avatar {
      float: left;
    }
    .comment-content {
      margin-left: 87px;
    }
    .post-content-comment .date {
      font-size: 12px;
      margin-left: 87px;
    }
    .comment-content h6 {
      font-weight: 700;
      color: #fff;
      font-size: 17px;
    }
    .date .c_reply a {
      padding-left: 20px;
      margin-left: 20px;
      border-left: solid 1px #ddd;
      font-size: 12px;
      display: inline-block;
      line-height: 12px;
    }
    .comments-box h4, .comment-respond h4, .comment-respond h3 {
      font-size: 17.5px;
      margin-bottom: 30px;
      text-transform: uppercase;
      letter-spacing: .5px;
      font-weight: 600;
    }
    .comment-form input[type='text'],.comment-form input[type='email'] {
      width: 100%;      
      border: 1px solid #E4DBDB;      
      padding: 5px;
      background-color: transparent;
      font-weight: 400;
      border-radius: 4px;
      font-size: 14px;
      box-shadow: none;
    }
    .comment-form textarea {
      width: 100%;
      height: 180px;
      border: 1px solid #E4DBDB;
      margin-bottom: 20px;
      padding: 5px;
      background-color: transparent;
      font-weight: 400;
      border-radius: 4px;
      font-size: 14px;
      box-shadow: none;
    }
    .form-submit #submit {
      padding: 6px 12px;
      transition: all 0.5s;
      color: #ffffff;
      border-radius: 4px;
      border: none;
      width: auto;
      margin-right: 15px;
    }
    .form-submit #submit:hover {
      background-color: #bbb;
    }
    .blog-slide{
        padding:0;
        margin:0;
    }


    
/* ================================================== */
/* contact form */
/* ================================================== */
    .wpcf7{margin-top:20px;}
    .wpcf7 input[type=text],
    .wpcf7 input[type=email],
    .wpcf7 input[type=tel],
    .wpcf7 input[type=number],
    .wpcf7 select.wpcf7-select,
    .wpcf7 textarea, #search, .woocommerce .woo-search-field {
        padding:10px;
        margin-bottom:20px;
        color:#fff;
        border:solid 1px rgba(0,0,0,.3);
        background:rgba(0,0,0,.2);
        border-radius:0 ;
        height:auto;
    }

    .wpcf7 input[placeholder],
    .wpcf7 textarea[placeholder]{
		color:#eee;
    }
    .wpcf7 input[type=submit]{
		background:none;
    }    
    .wpcf7 input[type=submit]:hover{
		color:#fff ;
		background:#111;
		border-color:#111;
    }    
    .wpcf7 textarea{height:176px;}
    span.wpcf7-not-valid-tip{
		margin-top: -15px;
		margin-bottom: 15px;
		color: #f00;
		font-size: 0.87em;
		display: block;
    }
    .wpcf7-not-valid-tip{
        display: none;
    }
    .wpcf7-form-control.wpcf7-text.wpcf7-not-valid{
        border-color: #D31E2B ;
    }
    .wpcf7-form-control.wpcf7-textarea.wpcf7-not-valid{
        border-color: #D31E2B ;
    }	
    .error_input{
		border-color:#D31E2B ;
    } 
	.wpcf7 input[type=text], 
	.wpcf7 input[type=email], 
	.wpcf7 input[type=tel],
	.wpcf7 input[type=number],
	.wpcf7 select.wpcf7-select{
		padding: 10px;
		margin-bottom: 20px;
		color: #fff;
		border: solid 1px rgba(0,0,0,.3);
		background: rgba(0,0,0,.2);
		border-radius: 0;
		height: auto;
		width: 100%;
	}
	.wpcf7 textarea{
		width: 100%;
		height: 175px;
		padding: 10px;
		margin-bottom: 20px;
		color: #fff;
		border: solid 1px rgba(0,0,0,.3);
		background: rgba(0,0,0,.2);
		border-radius: 0;
	}
	div.wpcf7-validation-errors{
		display: none;
	}
    .form_light .wpcf7 input[type=text],
    .form_light .wpcf7 input[type=email],
    .form_light .wpcf7 input[type=tel],
    .form_light .wpcf7 input[type=number],
    .form_light .wpcf7 select.wpcf7-select,
    .form_light .wpcf7 textarea{
        border: solid 1px #ddd;
        background: #f5f5f5;
        color: #333;
    }
    .no-bg {
        background: none !important;
    }

/* ================================================== */
/* coming soon page */
/* ================================================== */
    
    .coming-soon .logo{
        margin:0;
        padding:0;
    }
    
    .coming-soon h2{
        margin-top:0;
        color:rgba(255,255,255,.8);
        font-weight:400;
    }
    
    .coming-soon  .social-icons i{
        font-size:20px;
        margin-left:10px;
        margin-right:10px;
    }
    
    .coming-soon .social-icons i:hover{
        background:none;
        color:rgba(255,255,255,.2) ;
    }
    
    
    .arrow-up, .arrow-down {
        width: 0; 
        height: 0; 
        border-left: 40px solid transparent;
        border-right: 40px solid transparent;
        border-bottom: 40px solid #fff;
        position:fixed;
        margin-left: auto;
        margin-right: auto;
        left: 0;
        right: 0;
        bottom:0;
        cursor:pointer;
        z-index:101;
    }
    
    .arrow-down {
        border-top: 40px solid #fff;
        border-bottom:none;
        position:fixed;
        z-index:102;
        top:-40px;
    }
    
    .arrow-up:before{
        font-family:"FontAwesome";
        font-size:20px;
        content:"\f067";
        color:#222;
        position:relative;
        top:12px;
        margin:0 0 0 -8px ;
    }
    
    .arrow-down:before{
        font-family:"FontAwesome";
        font-size:20px;
        content:"\f068";
        color:#222;
        position:relative;
        top:-35px;
        margin:0 0 0 -8px ;
    }
    

/* ================================================== */
/* elements */
/* ================================================== */
    
    /* address */
    /* ------------------------------ */
    address{
        margin:0;
        margin-top:20px;
    }
    address div, address span {
        display: block;
        border-bottom:solid 1px #222;
        padding-bottom:5px;
        margin-bottom:5px;
        font-weight:300;
    }
    
    address div strong, address span strong {
        display: inline-block;
        min-width: 60px;
		margin-right: 10px;
    }
    
    address div, address span{
        border-bottom-color:#222;
    }
    
    address div i, address span i {
        margin-top:5px;
        margin-right:20px;
        float:none;
    }
    
    address div strong, address span strong {
        display: inline-block;
    }
    
    address div a, address span a{
        color:#eceff3;
    }
    
    /* border */
    /* ------------------------------ */
    .small-border{
        height:1px;
        width:120px;
        background:#ccc;
        display:block;
        margin:0 auto;
        margin-top:20px;
        margin-bottom:30px;
    }
    
    /* breadcrumb */
    /* ------------------------------ */
    .crumb {
        color:#777;
        float: right;
        font-size: 12px;
    }
    
    .crumb li {
        display: inline;
        text-decoration: none;
        padding: 0 2px 0 2px;
    }
    
    .crumb a{
        text-decoration:none;
    }
    
    /* button */
    /* ------------------------------ */
    .btn-line, a.btn-line{
		border: solid 1px #222;
		color: #fff;
		font-weight: 500;
		font-size: 12px;
		border-radius: 0;
		-moz-border-radius: 0;
		-webkit-border-radius: 0;
		padding: 5px;
		padding-left: 30px;
		padding-right: 30px;
		text-transform: uppercase;
		display: inline-block;
		text-align: center;
		letter-spacing: 2px;
		text-decoration: none;
    }   
    .btn-line, 
    a.btn-line, 
    .added_to_cart{
		border: solid 1px rgba(255,255,255,.2) ;
		color: #fff;
    }
    .btn-line:hover, 
    a.btn-line:hover, 
    .added_to_cart:hover{
		background:#fff;
		color: #111 ;
		border-color:#fff;
    }
    .btn-line:after,  
    a.btn-line:after{
		color: #fff;
    }
    .btn-line:hover:after, 
    a.btn-line:hover:after, 
    a.btn-line.hover:after{
		color: #fff;
    }
    .btn-line:hover:after, 
    a.btn-line:hover:after, 
    a.btn-line.hover:after, 
    .added_to_cart:hover:after{
		color: #111 ;
    }
    a.btn-text{
		text-decoration: none;
		display: inline-block;
		color: #111;
		font-weight: 600;
		padding: 0;
    }
    a.btn-text:after{
		font-family: FontAwesome;
		content: "\f054";
		padding-left: 10px;
    }
    a.btn-text {
		color: #fff ;
    }           
    .btn-line, a.btn-line {
		color: #eceff3;
    }    
    .btn-line:after, a.btn-line:after {
		font-family: FontAwesome;
		content: "\f054";
		margin-left: 10px;
    }          
    .btn-fullwidth {
		width: 100%;
    }    
    a.btn-slider {
		font-size: 13px;
		font-weight: bold;
		color: #fff;
		letter-spacing: 3px;
		line-height: normal;
		text-decoration: none;
		text-transform: uppercase;
        display: inline-block;
		border: solid 2px #fff;
		padding: 10px 30px 10px 30px;
    }
    a.btn-slider:hover {
		color: #222;
		background: #fff;
		border-color: #000;
		border: solid 2px #fff;
    }
    a.btn-slider:hover:after {
		color:#222 ;
    }
    a.btn-custom {
        font-size: 13px;
        color: #222;
        letter-spacing: 3px;
        line-height: normal;
        text-decoration: none;
        text-transform: uppercase;
        padding: 7px 25px 7px 25px;
        background: #fff;
        display: inline-block;
    }
    a.btn-big {
        font-size: 14px;
        color: #eceff3;
        letter-spacing: 1px;
        line-height: normal;
        font-weight: bold;
        text-transform: uppercase;
        display: inline-block;
        border: solid 1px #fff;
        padding: 10px 30px 10px 30px;
    }
    a.btn-big:after {
        font-family: FontAwesome;
        content: "\f054";
        margin-left: 20px;
    } 
    a.btn-line-black {
        border:solid 1px #111;
        color: #111;
        border-radius: 0;
        -moz-border-radius: 0;
        -webkit-border-radius: 0;
        font-weight: normal;
        display: inline-block;
    }    
    a.btn-line-black:hover {
        background: #111;
        color: #fff;
    }    

    a.btn-line-light {
        border: solid 1px #fff;
        color: #fff;
    }    
    a.btn-line-light:hover {
        background: #fff;
        color: #111;
    }      

    /* columns */
    /* ------------------------------ */

    
    /* counter */
    /* ------------------------------ */
    .de_count {
		text-align:center;
		padding:30px 0 30px 0;
		background:none;
    }
    .de_count h3 {		
		font-size:40px;
		font-weight:600;
    }
    .de_count span {
		text-transform:uppercase;
    }
    .de_count i {
        display:block;
        font-size:60px;
        margin:0 auto;
        margin-bottom:20px;
        width:100%;
        font-weight:lighter ;
    }
        
    /* divider */
    /* ------------------------------ */
    .spacer-single {
		width:100%;
		height:30px;
		display:block;
		clear:both;
    }
    .spacer-single-10 {
		width:100%;
		height:10px;
		display:block;
		clear:both;
    }
    .spacer-double {
		width:100%;
		height:60px;
		display:block;
		clear:both;
    }
    
    .spacer-half {
		width:100%;
		height:15px;
		display:block;
		clear:both;
    }
    hr {
		display: block;
		clear: both;
		border-top: solid 1px #ddd;
		margin: 40px 0 40px 0;
    }
    .double-divider {
        border-top: 1px solid rgb(223, 229, 232);
        margin-top: 40px;
        display: block;
        margin-bottom: 45px;
    }
    
    /* dropcap */
    /* ------------------------------ */
    .dropcap {
		display: inline-block;
		font-size: 48px;
		float: left;
		margin: 10px 15px 15px 0;
		color:#eceff3;
		padding: 20px 10px 20px 10px;
    }
    
    /* heading */
    /* ------------------------------ */
    h1, h2, h3, h4, h5, h6 {
		color: #000;
		font-weight:400;
    }    
    h1 {
		font-size:32px;
		margin:0;
		text-align:center;
		letter-spacing:2px;
		text-transform:uppercase;
		font-weight:300;
    }    
    h1 .small-border{
        margin-top:30px;
    }
    h2 {		
		font-weight:500;
		margin-bottom:30px;
		line-height:1.2em;
    }
    h2 .small-border{
		margin-left:0;
		margin-bottom:15px;
		width:40px;
    }    
    h3 {
		margin-top: 0;
		font-size:18px;
		letter-spacing:3px;
		text-transform:uppercase;
    }
    .teaser-text-3 {
        margin-top: 0;
        font-size:18px;
        letter-spacing:3px;
        text-transform:uppercase;
    }
    h1.slogan_big {
		font-weight: 300;
		font-size: 64px;
		line-height: 64px;
		letter-spacing: -2px;
		padding: 0;
		margin: 0px 0 30px 0;
    }
    h1.title{
		font-size:64px;
		letter-spacing:10px;
    }
    h1.title strong{		
		text-transform:none;
		letter-spacing:0;
		font-weight:normal;
    }
    h1.title-2{
        letter-spacing:20px;
        text-transform:uppercase;
        line-height:50px;
    }
    h1.title-3{
        font-size:72px;
    }
    h1.title-3 strong{
        text-transform:none;
        letter-spacing:0;
        font-weight:normal;
    }
    h1.title.s2 {
        font-size: 64px;
        letter-spacing: 0px;
    }
    h2.subtitle{
        margin-top:0;
    }
    h2.hero {
        font-size: 32px;
        font-weight: 400;
        letter-spacing: 32px;
        text-transform: uppercase;        
    }
    h2.style-2 {
        font-size:12px;
        font-weight:bold;
        text-transform:uppercase;
        letter-spacing:10px;
    }    
    h2.style-3 {
        font-size:64px;
        font-weight:400;
        text-transform:uppercase;
        letter-spacing:20px;
    }
    h2.style-4 {
        font-size:60px;
        font-weight:400;
        text-transform:normal;
        letter-spacing:-2px;
    }
    h2.style-5 {
        margin-top:0;
        line-height:1.2em;
        font-size:48px;
        font-weight:400;
        text-transform:normal;
    }
    h3.title {
		border-bottom: solid 1px #ddd;
		margin-bottom: 20px;
    }
    h4.title {
		border-bottom: solid 1px #ddd;
		padding-bottom: 10px;
		margin-bottom: 20px;
    }
    h5 {
		font-weight: bold;
    }
    h1,
    h2,
    h3,
    h4,
    h5{
		color:#eceff3;
    }

    h3.s2 b{
        font-family:"Allura";
        text-transform:none;
        letter-spacing:0;
        font-size:40px;
        display:block;
    }
    
    h3.s2{
        font-size:30px;
    }

    h3.style-1{
        font-family: 'Open Sans', sans-serif;
        letter-spacing:0;
        text-transform:none;
        margin-bottom:20px;
    }

    .typing-wrap{
        font-size:30px;
        margin:0;
        line-height:60px;
    }
    .text-dark, .text-dark h1, .text-dark h2, .text-dark h3 {
        color: #222;
    }
    .text-light{
		color:#ddd;
    }
    
    .text-light h1{
		color:#fff ;            
    }
    .text-light h1, .text-light h2, .text-light h3, .text-light h4, .text-light h5 {
        color: #fff;
    }
    .no-relative .vc_column_container {position: static;}
    
    /* feature box style 1 */
    .feature-box i {
		border:solid 1px;
    }
    
    .feature-box-small-icon {
		margin-bottom: 30px;
    }
    
    .feature-box-small-icon.center{
		text-align:center;
    }
    
    .feature-box-small-icon .inner:hover > i {
		color:#fff;
    }
    
    .feature-box-small-icon .text {
		padding-left: 70px;
    }
    
    .feature-box-small-icon.center .text{
		padding-left:0;
		display:block;
    }
    
    .feature-box-small-icon i {
		text-shadow:none;
		color: #333;
		font-size: 32px;
		width: 68px;
		height: 68px;
		text-align: center;
		position: absolute;
		border-radius:60px;
    }
    
    .feature-box-small-icon i.hover {
		color:#333 ;
    }
    
    .feature-box-small-icon i.hover {
		color:#fff ;
    }
    
    .feature-box-small-icon .border{
		height:2px;
		width:30px;
		background:#ccc;
		display:block;
		margin-top:20px;
		margin-left:85px;
    }
    
    
    .feature-box-small-icon .btn{
    margin-top:10px;
    }
    
    .feature-box-small-icon.center i{
		position:inherit;
		float:none;
		display:inline-block;
		margin-bottom:20px;
		border:none;
		font-size:60px;
		background:none;
		padding:0px;
    }
    
    .feature-box-small-icon.center .fs1{
    position:inherit;
    float:none;
    display:inline-block;
    margin-bottom:20px;
    border:none;
    font-size:60px;
    background:none;
    padding:0px;
    }
    

    .feature-box-small-icon i{
    background-color: #333333;
    }
    
    .feature-box-small-icon h3 {
    line-height: normal;
    margin-bottom: 5px;
    }
    
    .feature-box-small-icon.no-bg h2 {
    padding-top:12px;
    }
    
    .feature-box-small-icon.no-bg .inner, .feature-box-small-icon.no-bg .inner:hover{
		padding:0;
		background:none;
    }
    
    .f-hover{
		-o-transition:.5s;
		-ms-transition:.5s;
		-moz-transition:.5s;
		-webkit-transition:.5s;
		transition:.5s;
		 outline: none;
    }
    
    /* feature-box style 2 */
    .feature-box i {
		border:solid 1px;
    }
    
    .feature-box-small-icon-2 {
		margin-bottom: 30px;
    }
    
    .feature-box-small-icon-2 .text {
		padding-left: 48px;
    }
    
    .feature-box-small-icon-2 i {
		text-shadow:none;
		color:#eceff3;
		font-size: 24px;
		text-align: center;
		position: absolute;
    }
    
    .feature-box-small-icon-2 i{
		background-color: #333333;
    }
    
    .feature-box-small-icon-2 h3 {
		line-height: normal;
		margin-bottom: 5px;
    }
    
    .feature-box-small-icon-2.no-bg h2 {
		padding-top:12px;
    }
    
    .feature-box-small-icon-2.no-bg .inner, .feature-box-small-icon-2.no-bg .inner:hover{
		padding:0;
		background:none;
    }
    
    
    /* feature-box image style 3 */
    .feature-box i {
		border:solid 1px;
    }
    .feature-box-image-2 {
		margin-bottom: 30px;
    }
    .feature-box-image-2 .text {
		padding-left: 100px;
    }
    .feature-box-image-2 img {
		position: absolute;
    }
    .feature-box-image-2 i{
		background-color: #333333;
    }
    .feature-box-image-2 h3 {
		line-height: normal;
		margin-bottom: 5px;
    }
    .feature-box-image-2.no-bg h2 {
		padding-top:12px;
    }
    .feature-box-image-2.no-bg .inner, .feature-box-image-2.no-bg .inner:hover{
		padding:0;
		background:none;
    }
    
    /* with image */
    .feature-box-image img{
		width:100%;
		margin-bottom:10px;
		height:auto;
    }
    .feature-box-image h3 {
		line-height: normal;
		margin-bottom: 5px;
		font-size:20px;
		font-weight:bold;
    }
    
    /* feature-box image style 4 */
    .feature-box-big-icon{
		text-align:center;
    }
    
    .feature-box-big-icon i {
		float:none;
		display:inline-block;
		text-shadow:none;
		color:#eceff3;
		font-size: 40px;
		padding: 40px;
		width: 120x;
		height: 120x;
		text-align: center;
		border:none;
		border-radius:10px;
		-moz-border-radius:10px;
		-web-kit-border-radius:10px;
		background:#333;
		margin-bottom:40px;		
		cursor:default;    
    }
    .feature-box-big-icon i:after {
		content: "";
		position:absolute;
		margin:75px 0 0 -40px;
		border-width: 20px 20px 0 20px; /*size of the triangle*/
		border-style: solid;
    }
    
    .feature-box-big-icon:hover i,
    .feature-box-big-icon:hover i:after{
		-o-transition:.5s;
		-ms-transition:.5s;
		-moz-transition:.5s;
		 -webkit-transition:.5s;
		 transition:.5s;
    }
    .feature-box-big-icon:hover i{
		background:#333;
    }
    .feature-box-big-icon:hover i:after{
		border-color:#333 transparent;
    }
    
    
    .box-fx .inner{
		position:relative;
		overflow:hidden;
		border-bottom:solid 2px;
    }
    
    .box-fx .inner{
		border-bottom:solid 2px;
    }
    
    .box-fx .front{
		padding:60px 0 60px 0;
    }
    
    .box-fx .front span{
		font-size:14px;
    }
    
    .box-fx .info{
		position:absolute;
		padding:60px 30px 60px 30px;
		background:#fff;
		color:#fff;
    }
    
    .box-fx i{
		font-size:72px ;
		margin-bottom:20px;
    }
    
    .box-fx .btn-line, .box-fx .btn-line a.btn-line{
		border:solid 1px rgba(255,255,255,0.5);
		color:#fff ;
    }
    
    .box-fx .btn-line:hover, .box-fx a.btn-line:hover{
		background:#fff;
		color:#111 ;
		border-color:#fff;
    }
    
    .box-fx .btn-line:after, .box-fx a.btn-line:after{
		color:#fff ;
    }
    
    .box-fx .btn-line:hover:after, .box-fx a.btn-line:hover:after, .box-fx a.btn-line.hover:after{
		color:#111 ;
    }
    
    .box-fx .bg-icon{
        left:50%;
        bottom:50px;
        color:#f5f5f5 ;
        position:absolute ;
        font-size:190px ;
        z-index:-1;
    }

    .box-icon-simple i{
        font-size:42px;
        position:absolute;
        float: none;
        margin: 0px;
    }
    .box-icon-simple.right{margin-right:70px;text-align:right;}
    .box-icon-simple.right i{right:0;}    
    .box-icon-simple.left{margin-left:70px;}
    .box-icon-simple.left i{left:0;}
    .box-icon-simple.center i{position: static;margin-bottom: 25px;}
    .box-icon-simple.center h3{margin-bottom: 15px;}
    
    .box-number .number{
        display:block;
        font-size:48px;
        color:#222;
        width:80px;
        height:80px;
        text-align:center;
        padding: 0px 0px;
        border-radius:60px;
        position:absolute;
        line-height: 80px;
    }
    .box-number.square .number {
        border-radius: 0;
    }
    .box-number .text{
        margin-left:100px;
    }

    .box-number i {
        float: none;
        margin: 0px;
    }

    .box-icon .icon{
        display:block;
        font-size:48px;
        color:#222;
        text-align:center;
        border-radius:60px;
        position:absolute;
        cursor:default;
    }
    
    .box-icon .text{
        margin-left:80px;
    }

    .box-none .number {
        background: transparent;
    }

    .icon-img {display: block;position: absolute;width: 50px;}
    .icon-img img{max-width: 100%;}
    .box-icon-simple.right .icon-img{right: 0px;}
    .box-icon-simple.left .icon-img{left: 0px;}
    .box-icon-simple.center .icon-img {position: static;width: 100%;text-align: center;margin-bottom: 28px;}
    .box-icon.border{
        border:solid 1px rgba(255,255,255,.1);
        padding:40px;
        border-radius:3px;
        -moz-border-radius:3px;
        -webkit-border-radius:3px;
    }    
    .box-icon.border.active,
    .box-icon.border:hover{
        background:rgba(255,255,255,.1);
        border-color:rgba(255,255,255,.0);
    }    
    .box-icon.border a{
        text-decoration:none;
    }
    .strong {
        font-weight: bold;
    }

    .shadow-soft {
        box-shadow: 2px 2px 20px 0 rgba(0, 0, 0, 0.4);
    }

    /* list */
    .ul-style-2{
        padding:0;
        list-style:none;
    }
    
    .ul-style-2 li{
        margin:5px 0 5px 0;
    }
    
    .ul-style-2 li:before{
        font-family:"FontAwesome";
        content:"\f00c";
        margin-right:15px;
    }
    
    /* pagination */
    /* ======================================== */    
    .page-numbers {display: inline-block;list-style: none;padding: 0px;margin: 0px;}
    .page-numbers li {display: inline-block;float: left;margin: 3px;}
    .pagination {
        display: inline-block;
        text-align: center;
        width: 100%;
    }
    .pagination > li {
        display: inline-block;
    }
    .pagination li a:hover{
        color:#fff;
        background:none; 
        border-color: #fff;   
    }
    .page-numbers li a.next, .page-numbers li a.prev {padding: 0px;}    
    .pagination li a i{
        margin-left: 0;
        margin-right: 0;
        float: none;
    }
    .pagination li a{
        color:#888;
        border:solid 1px #404040;
        background:none;
        width: 50px;
        height: 50px;
        line-height: 50px;
        text-align: center;
        display: block;
        margin:0px;
        padding:0px;            
        -moz-border-radius:0;
        -webkit-border-radius:0;
        text-decoration: none;
    }
    .pagination li span{
        color:#fff;
        border:solid 1px #404040;
        background:none;
        margin:0px;
        padding:0px; 
        width: 50px;
        height: 50px;
        line-height: 50px;
        text-align: center;
        display: block;   
        border-top-left-radius: 0px;
        border-bottom-left-radius: 0px;
        border-top-right-radius: 0px;
        border-bottom-right-radius: 0px;
        -moz-border-radius:0;
        -webkit-border-radius:0;
    }
    .w100 {width: 100%;}

     /* -------------------------------------------------- */
	/* pricing table */
	/* -------------------------------------------------- */
	.pricing-2-col {
		border-right: solid 1px #eee;
	}

		.pricing-2-col .pricing-box {
			width: 50%;
		}

	.pricing-3-col {
		border-right: solid 1px #eee;
	}

		.pricing-3-col .pricing-box {
			width: 33.33%;
		}

	.pricing-4-col {
		border-right: solid 1px #eee;
	}

		.pricing-4-col .pricing-box {
			width: 25%;
		}

	.pricing-5-col {
		border-right: solid 1px #eee;
	}

		.pricing-5-col .pricing-box {
			width: 20%;
		}

		.pricing-2-col.pricing-dark,
		.pricing-3-col.pricing-dark,
		.pricing-4-col.pricing-dark,
		.pricing-5-col.pricing-dark {
			border-right: solid 1px #404040;
		}

	.pricing-box {
		float: left;
		text-align: center;
		margin: 0;
		padding: 0;
	}
    .pricing-box h1, .de_light .pricing-box h1 {
        font-size: 48px;
        margin: 0;
        margin-bottom: 5px;
        font-weight: 600;
        color: #fab207;
    }
	.pricing-box:last-child{
		border-right: 1px solid #F5F5F5;
	}

		.pricing-box ul {
			margin: 0;
			padding: 0;
			border-left: solid 1px #F5F5F5;
			border-top: solid 1px #eee;
			background-color: #f5f5f5;
		}

		.pricing-box li, .btn-row {
			list-style: none;
			margin: 0;
			padding: 15px 0 15px 0;
			border-bottom: solid 1px #eee;
		}
		.pricing-box li {
			color: #888;
		}		

			.pricing-box .title-row {
				padding: 15px 0 15px 0;
				border-left: solid 1px #F5F5F5;
				border-top: solid 1px #eee;
				margin: 0;
				background-color: #eee;
			}

			.pricing-box .price-row {
				background: #f8f8f8;
				padding: 15px 0 15px 0;
				border-left: solid 1px #F5F5F5;
				border-top: solid 1px #eee;
				color: #888;
			}

				.pricing-box .price-row span {
					display: block;
					font-weight: 600;
				}

			.pricing-box .btn-row {
				background: #ddd;
				border-left: 1px solid #F5F5F5;
			}			
			.pricing-box .btn-row .btn:hover {background: #363636;}

	.pricing-dark.pricing-box ul {
		margin: 0;
		padding: 0;
		border-left: solid 1px #555;
		border-top: solid 1px #555;
	}

	.pricing-dark.pricing-box li {
		background: #606060;
		color: #fff;
		list-style: none;
		margin: 0;
		padding: 15px 0 15px 0;
		border-bottom: solid 1px #555;
	}

	.pricing-box li:nth-child(2n-1){
		background-color: #eee;
	}
		.pricing-dark.pricing-box h4 {
			font-size: 22px;
			margin: 0;
			padding: 0;
			font-weight: 400;
			color: #fff;
		}        
		.pricing-dark.pricing-box h1 {
			color: #fff;
		}

		.pricing-dark.pricing-box .title-row {
			padding: 15px 0 15px 0;
			border-left: solid 1px #555;
			border-top: solid 1px #555;
			background: #606060;
		}

		.pricing-dark.pricing-box .price-row{
			border-left: solid 1px #555;
			border-top: solid 1px #555;
			background: #777;
			padding: 15px 0 15px 0;
			background-color: #fab207;
		}

		.pricing-dark.pricing-box li{
			background: #606060;
		}
		.pricing-dark.pricing-box li:nth-child(2n){
			background: #555;
		}

			.pricing-dark.pricing-box .price-row span {
				display: block;
				font-weight: 600;
				color: #fff;
			}

		.pricing-dark.pricing-box .btn-row {
			background: #404040;
			border-left: solid 1px #555;
			border-bottom: solid 1px #555;
		}
		.pricing-dark.pricing-box .btn-row .btn:hover {background: #000;}		
		
		.pricing-dark:last-child{
			border-right: 1px solid #555;
		}


	.pricing-featured {
		-webkit-box-shadow: 1px 1px 20px rgba(0, 0, 0, 0.3);
		-moz-box-shadow: 1px 1px 20px rgba(0, 0, 0, 0.3);
		box-shadow: 1px 1px 20px rgba(0, 0, 0, 0.3);
		position: relative;
		margin-top: -10px;
	}
	.pricing-featured li{
		padding-top: 17px;
		padding-bottom: 17px;
	}

	.pricing-featured.pricing-box > *{
		border-left: none;
	}
    .pricing-box h4 {
        color: #606060;
        font-size: 22px;
        font-weight: 400;
    }

    /* New Pricing Tables */

    .pricing-s1 {
        overflow:hidden;
        position:relative;
        border-radius: 3px;
        -webkit-border-radius: 3px;
        -moz-border-radius: 3px;
        transition: box-shadow 1s;
        -webkit-transition: box-shadow 1s;
        -moz-transition: box-shadow 1s;
    }
    .pricing-s1 .top {
        background: #222427;
        color: #eee;
        padding: 40px;
        color: #ECF0F1;
        text-align: center;
    }
    .pricing-s1 .top h2 {
        font-size: 24px;
        margin-bottom: 20px;
        font-weight: normal;
    }
    .pricing-s1 .top > * {
        margin: 0px;
    }
    .pricing-s1 .top .price .currency {
        font-size: 24px;
        line-height: 54px;
        vertical-align: top;
        display: inline-block;
    }
    .pricing-s1 .top .price b {
        font-size: 48px;
        line-height: 70px;
        color: #fff;
    }
    .pricing-s1 .top .price .month {
        color: #ccc;
    }
    .pricing-s1 .bottom {
        border-top: 0px;
        padding-bottom:5px;
        background: #222427;
        text-align:center;  
    }
    .pricing-s1 .bottom ul {
        list-style: none;
        list-style-type: none;
        margin: 0px;
        padding: 0px;
        text-align:left;
    }
    .pricing-s1 .bottom ul li {
        line-height: 60px;
        padding: 0px 30px;
    }
    .pricing-s1 .bottom ul li > span {
        color: #16A085;
        font-size: 20px;
        margin-right: 20px;
    }
    .pricing-s1 .bottom ul li:nth-child(odd) {
        background:#2f3135;
    }
    .pricing-s1 .bottom ul li:nth-child(even) {
        background:#2a2c30
    }
    .pricing-s1 .bottom > a {
        margin: 40px;
        width: auto;
    }
    .pricing-s1 .bottom i{
        margin-right:10px;
        float: none;
    }
    .pricing-s1 .ribbon{
      width: 200px;
      position: absolute;
      top: 20px;
      left: -55px;
      text-align: center;
      line-height: 50px;
      letter-spacing: 1px;
      color: #222;
      font-weight:bold;
      transform: rotate(-45deg);
      -webkit-transform: rotate(-45deg);
      -moz-transform: rotate(-45deg);
    }    
    
    /* progress bar */
    /* ================================================== */
    
    .de-progress{
        width:100%;
        height:8px;
        background:#ddd;
        margin-top:20px;
        margin-bottom:20px;
        border-radius:40px;
        -moz-border-radius:40px;
        -webkit-border-radius:40px;    
    }
    
    .de-progress .progress-bar{
        background:#333;
        height:8px;
        border-radius:40px;
        -moz-border-radius:40px;
        -webkit-border-radius:40px;
    }
    
    .de-progress{
        background:#000;
    }
    
    
    /* social-icons */
    /* ================================================== */
    .social-icons{
        display:inline-block;
    }
    .social-icons ul{margin: 0px;padding: 0px;}
    .social-icons ul li{display: inline-block;list-style: none;margin-left: 5px;}
    .social-icons ul li a{
        display: block;
        text-shadow:none;                
        width: 28px;
        height: 28px;
        line-height: 28px;
        font-size:16px;
        border-radius:1px;
        -moz-border-radius:1px;
        -webkit-border-radius:1px;
        text-align: center;
        color: #fff;
    }
    .social-icons ul li a:hover{
        background:#fff;
        border-color:#fff;

    }
    .social-icons ul li a i{
        padding: 0px;
        margin: 0px;
        float: none;        
    }
    .social-icons ul li a:hover{color:#333;}
    
    /* tabs */
    /* ================================================== */
    .de_tab {
        opacity:.8;
    }
    
    .de_tab .de_nav {
        overflow: hidden;
        padding-left: 0;
        margin: 0;
        padding: 0;
        font-weight:bold;
    }
    
    .accordion-inner img.full-size{
        margin-top:5px;
        margin-bottom:10px;
    }
    
    a.accordion-toggle,a:visited.accordion-toggle{
        font-weight:bold;
        color:#222;
    }
    
    .de_tab .de_nav li {
        float: left;
        list-style: none;
        background: #EEE;
        margin-right: 5px;
    }
    
    .de_tab .de_nav li span {
        padding: 8px 16px 8px 16px;
        border-top: 1px solid #ddd;
        border-bottom: 1px solid #ddd;
        border-left: 1px solid #ddd;
        border-right: 1px solid #ddd;
        display: block;
        background: #f5f5f5;
        text-decoration: none;
        color: #646464;
        font-size: 13px;
        cursor: pointer;
    }
    
    .de_tab.tab_steps .de_nav{
        text-align:center;  
    }
    .de_tab.tab_steps .de_nav li{
        background:none;
        display:inline-block;
        float:none;
        margin:0 30px 0px 30px;
    }
    
    .de_tab.tab_steps .de_nav li span {        
        font-size:16px;
        line-height:120px;
        color:#222;
        border-radius:120px;
        -moz-border-radius:120px;
        -webkit-border-radius:120px;        
        padding:30px 0 30px 0;
        width:180px;
        height:180px;
        text-align:center;
        text-transform:uppercase;        
    }

    .de_tab.tab_steps.tab_5 .de_nav li span{
        font-size: 15px;
        height: 140px;
        line-height: 85px;
        padding: 25px 0;
        width: 140px;
    }
    
    .de_tab.tab_steps.tab_6 .de_nav li span {
        font-size: 14px;
        height: 120px;
        line-height: 70px;
        padding: 20px 0;
        width: 120px;
    }

    .de_tab.tab_steps .de_nav li span:hover{
        background:#000;
        border: 2px solid transparent;
        color:#fff;
    }
    
    .de_tab.tab_steps .de_nav li .v-border{
        height:60px;
        border-left:solid 1px rgba(255,255,255,.3);
        display:inline-block;
        margin-bottom:-6px; 
    }

    .dark .de_tab.tab_steps .de_nav li .v-border{
        border-left:solid 1px rgba(0,0,0,.3);
    }
    
    .de_tab .de_nav li span {
        border: 2px solid #fab702;
        background:#222;
    }
    
    .de_tab .de_tab_content {
        border: 1px solid #ddd;
        padding: 15px 20px 20px 20px;
        margin-top: -1px;
        background: #fff;
    }
    
    .de_tab .de_tab_content {
        border: 1px solid #404040;
        background: #27282b;
    }
    
    .de_tab.tab_steps .de_tab_content {
        background:0;
        padding:0;
        border:none;
        padding-top:30px;
        border-top:solid 1px rgba(255,255,255,.4);
    }

    .dark .de_tab.tab_steps .de_tab_content {
        border-top:solid 1px rgba(0,0,0,.4);
    }
    
    .de_tab .de_nav li.active span .v-border{
        display:none ;
    }
    
    .de_tab .de_nav li.active span {
        background: #27282b;
        border: 2px solid #27282b;
        color: #ccc;
        margin-bottom: 0px;
    }
    
    .de_tab.tab_steps .de_nav li.active span {
        background:none;
        color: #ffffff;
        border:solid 2px rgba(255,255,255,.8);
    }
    
    .dark .de_tab.tab_steps .de_nav li.active span {
        background:none;
        color: #333;
        border:solid 2px rgba(0,0,0,.8);
    }   

    .de_tab.tab_steps.tabs-square .de_nav li span {
        border-radius:0px;
        -moz-border-radius:0px;
        -webkit-border-radius:0px;
    }

    .de_tab.tab_steps.tabs-square .de_nav li.active span {
        border-width: 5px;
    }

    .tab-small-post ul {
        list-style: none;
        margin: 0;
        padding: 0;
    }
    
    .tab-small-post ul li {
        min-height: 60px;
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: solid 1px #eeeeee;
    }
    
    .tab-small-post ul li{
        border-bottom: solid 1px #404040;
    }
    
    .tab-small-post ul li:last-child {
        border-bottom: none;
        margin-bottom: 0;
        padding-bottom: 0;
    }
    
    .tab-small-post ul li img {
        position: absolute;
    }
    
    .tab-small-post ul li span {
        display: block;
        padding-left: 64px;
    }
    
    .tab-small-post ul li span.post-date {
        font-size: 11px;
    }

    .de_tab.tab_steps .de_nav.process-circle-textimage .content-mid, 
    .de_tab.tab_steps .de_nav.process-circle-textonly .content-mid,
    .de_tab.tab_steps .de_nav.process-circle-icon .content-mid, 
    .de_tab.tab_steps .de_nav.process-circle-texticon .content-mid {
        text-align: center;
        line-height: normal;
        display: table;
    }
    .de_tab.tab_steps .de_nav.process-circle-textimage .content-mid .inner,
    .de_tab.tab_steps .de_nav.process-circle-textonly .content-mid .inner,
    .de_tab.tab_steps .de_nav.process-circle-icon .content-mid .inner, 
    .de_tab.tab_steps .de_nav.process-circle-texticon .content-mid .inner {
        display: table-cell;
        vertical-align: middle;        
    }
    .de_tab.tab_steps .de_nav.process-circle-textimage img {
        display: inline-block;
        clear: both;
        max-width: 60px;
    }
    .de_tab.tab_steps .de_nav.process-circle-textimage small {
        display: inline-block;
        width: 100%;
        margin-top: 15px;
    }
    .de_tab.tab_steps .de_nav.process-circle-image img {
        max-width: 90px;
    }
    .de_tab.tab_steps .de_nav.process-circle-image small {
        display: none;
    }
    .de_tab.tab_steps .de_nav.process-circle-icon li i, 
    .de_tab.tab_steps .de_nav.process-circle-texticon li i {
        float: none;
        display: inline-block;
        margin: 0px;
        padding: 0px;
        font-size: 60px;
        width: 100%;
    }

    .timeline .tl-block{ position: relative; margin-top: 10px; }
    .timeline .tl-block:after{ content: ' '; clear: both; display: block;}
    .timeline .tl-block .tl-time{ float: left; padding:10px 20px 0px 20px; margin-top:-15px; border:solid 1px #ddd; }
    .timeline .tl-block .tl-time:after{width:50px; height:1px; background:#ddd;}
    .timeline .tl-block .tl-bar{float: left; width: 5%; position: absolute; }
    .timeline .tl-block .tl-line{background: #fff; margin-right: 10px;  border-radius: 10px; width: 6px; height: 6px; font-size: 10px; text-align: center; line-height: 15px;}
    .timeline .tl-message{ border-radius: 3px; float: left; top:0; margin-top:-50px; margin-bottom:30px; }
    .timeline .tl-block .tl-message:after{ display: block; content: ' '; clear:both; }
    .timeline .tl-block .tl-message .tl-icon{float: left; left:100px; }
    .timeline .tl-block .tl-message .tl-main{ float: left; }
    .timeline .tl-block .tl-message .tl-main .tl-title {}
    .timeline .tl-block .tl-message .tl-main .tl-content{}
    .timeline .tl-block .tl-message .tl-main .tl-content label{ font-weight: bold; display: inline-block; width: 80px;}
    .timeline .tl-block .tl-message .tl-main .tl-content span{}
    .timeline .tl-block .tl-message h3{text-transform:none;}
    .timeline .tl-block .tl-time h4{margin:0 0 10px 0;}
    .timeline .tl-block .tl-main h4{margin-top:-5px;}
    .timeline.exp .tl-message{margin-left:250px;}
    .timeline.exp .tl-block .tl-bar{margin-left:180px; }
    .timeline.exp{ margin-top: 20px; position: relative; padding: 10px}
    .timeline.exp:before{ 
        content: '';
        position: absolute;
        top: 0;
        left: 193px;
        height: 100%;
        width: 1px;
        background:rgba(255,255,255,.1);
    }

    .btn-left,
    .btn-right{
        background:none;
        border:solid 1px rgba(255,255,255,.2);
        padding:10px 20px 10px 20px;
        margin:5px;
        font-family:"Dosis";
        text-transform:uppercase;
        letter-spacing:5px;
    }
    
    .btn-right:after{
        font-family:FontAwesome;
        content: "\f054";
        padding-left:10px;
    }
    
    .btn-left:before{
        font-family:FontAwesome;
        content: "\f053";
        padding-right:10px;
    }
    
    a.btn-left,
    a.btn-right{
        text-decoration:none;
    }
    
    .expand-group .expand:last-child{
        border-bottom:solid 1px rgba(255,255,255,.1);
    }
    .expand{
        position:relative;
        padding:5px 25px 5px 25px;
        border:solid 1px rgba(255,255,255,.1);
        border-bottom:none;
        background:rgba(255,255,255,.02);
    }
    .expand-group .expand:nth-child(odd){
        background:rgba(255,255,255,.04);
    }
    .expand .hidden-content{
        display:none;
        padding:10px 0 10px 0;
    }
    .expand h4{
        font-family:"Open Sans";
        font-size:16px;
        cursor:pointer;
        display:block;
        margin-right:40px;
        line-height:32px;
    }
    
    .expand h4:after{
        font-family:FontAwesome;
        content: "\f107";
        color:#fff;
        font-size:20px;
        display:inline-block;
        padding:10px 20px 10px 20px;
        font-style:normal;
        position:absolute;
        right:7px;
        top:7px;
    }
    
    .expand h4.active:after{
        content: "\f106";
    }
    
    /* team
    /* ================================================== */
    /*Team Default*/
    .de-team-list{
        overflow:hidden;
        position: relative;
    }
    .de-team-list img{
        width:100%;
    }
    .de-team-list .team-desc{
        width:100%;
        height:100%;
        padding:20px;
        padding-bottom:0;
        position:absolute;
        z-index:100;
        top:100%;
        background:#111;
        color:#ccc;
    }
    .de-team-list p{
        clear:both;
    }
    .team-box .team-desc h3{
        color:#fff;
        margin-bottom:5px;
    }    
    .team-box p.lead{
        font-size:14px;
    }
    .team-box .small-border{
        float:none;
        margin:15px 0 15px 0;
        background:#ddd;
        width:50px;
    }
    .team-box .social a{
        display:inline-block;
        color: #fff;
    }
    .team-box .social a:hover{
        color:#888;
    }
    .de-team-list:hover .team-desc{
        top:0;
    }

    /*Team 2*/
    .de-team-list-2 .team-desc{
        padding:20px;
        background:#111;
        color:#ccc;
    }

    /* testimonial
    /* ================================================== */
    .de_testi {
        display: block;
        margin-bottom: 10px;
    }
    
    .de_testi blockquote {
        margin: 0;
        border: none;
        padding: 20px 30px 30px 80px;
        background:rgba(0,0,0,0.5);
        font-style:normal;
        line-height:1.6em;
        font-weight:500;
    }
    
    .de_testi blockquote  p{
        margin-top:10px;
    }
    
    .de_testi blockquote:before{
        font-family:FontAwesome;
        content: "\f10d";
        color:#111;
        padding-bottom:10px;
        font-size:20px;
        display:inline-block;
        padding:10px 20px 10px 20px;
        font-style:normal;
        background:#000;
        position:absolute;
        left:15px;
    }
    
    .de_testi blockquote {
        color:#eceff3;
    }
    
    .de_testi blockquote, .de_testi blockquote p {
        font-size:16px;
        line-height: 1.6em;
        font-weight: 400;
    }
    
    .de_testi_by {
        margin-top: 10px;
        margin-bottom: 10px;
        font-style:normal;
        font-size:12px;
    }

    .de_testi_by.no-margin{margin: 0px;margin-top: -10px;}
    
    .de_testi_pic {
        float: left;
        padding-right: 15px;        
		width: 70px;
		height: 70px;
    }
    
    .de_testi_pic img {
        width: 50px;
        height: 50px;
    }
    
    .de_testi_company {
        padding-top: 15px;
    }
    
    .testimonial-masonry .item{
        margin-bottom:30px;
    }

    blockquote.s1 {
        font-size: 16px;
        font-style: italic;
        font-weight:400;
        line-height: 1.7em;
        color:#333;
        background:#f8f8f8;
        padding:30px;
    }

    blockquote.s1{
        background:none;
        color:#fff;
        padding:0;
        border:none;
        padding:0 40px 40px 40px;
        margin-bottom:40px;
    }
    blockquote.s1  span.by{
        margin-top:20px;
    }

    blockquote.s1  span.by:before{
        content:"by ";
        color:rgba(255,255,255,.5);
    }

    blockquote.s1  span.rating{
        margin-bottom:20px;
        font-weight:normal;
    }
    blockquote.s1  span.rating i{
        margin:0 3px 0 3px;
        float: none;
    }

    .text-dark blockquote.s1{
        color:#606060;
    }
    .text-dark blockquote.s1  span.by:before{
        color:rgba(0,0,0,.5);
    }
    .text-dark .testimonial-new-slider.owl-theme .owl-controls .owl-page span{background: #606060 !important;}

/* ================================================== */
/* anim */
/* ================================================== */
.de_tab .de_nav li span,
.feature-box-small-icon i, a.btn-line:after, .de_count, .social-icons a i,
.de_tab.tab_steps .de_nav li span,
.de_tab.tab_steps .de_nav li span:hover,
.site__header.smaller:not(.header__bottom),
.wpcf7 input[type=submit],
.wpcf7 input[type=submit]:hover,
.product .product-thumb img, .flex-control-thumbs img,
.mfp-close,.mfp-close:hover,
.site__header .info,
.site__header.smaller .info,
.de_form input[type="radio"] + label,
.de_form input[type="checkbox"] + label,
.box-icon.border,
.de-team-list .team-desc, .de-team-list:hover .team-desc
{
    -o-transition:.5s;
    -ms-transition:.5s;
    -moz-transition:.5s;
    -webkit-transition:.5s;
    transition:.5s;
    outline: none;
}

/* ================================================== */
/* video */
/* ================================================== */
video, object {
    display:inline-block;
    vertical-align:baseline;
    min-width:100%;
    min-height:100%;
}

.de-video-container {
  top:0%;
  left:0%;
  width: 100%;
  height: 100%;
  overflow: hidden;
  position: relative;
}
/* https://stackoverflow.com/questions/27850472/html5-video-background-keep-center-of-video-in-center */
.de-video-container video {
  position: absolute;
  z-index: 1;
  top: 50%;
  left:50%;
  min-width: 100%;
  min-height: 100%;
  transform: translateX(-50%) translateY(-50%);
}
.de-video-content {
    width:100%;
    position:absolute;
    z-index:10;
}
.de-video-overlay{
    position: absolute;
    width: 100%;
    min-height: 100%;
    background: url(images/dot-70.png);
    z-index: 2;
}
.de-video-overlay.dotted{
    background:url(images/dotted.png);
}

.de-video-container .btn-line:hover:after, 
.de-video-container a.btn-line:hover:after, 
.de-video-container a.btn-line.hover:after{
    color:#eceff3;
}

/* ================================================== */
/* map */
/* ================================================== */
.map iframe {
    width: 100%;
    height: 320px;
    border: solid 1px #ccc;
    padding: 2px;
    background: #fff;
}

.map-container{
    height: 500px;
    overflow:hidden;
}

/* ================================================== */
/* call to action */
/* ================================================== */
.call-to-action-box {
    background: #f5f5f5;
    border: solid 1px #ddd;
    background: rgb(255,255,255); /* Old browsers */
    background: -moz-linear-gradient(top, rgba(255,255,255,1) 0%, rgba(242,242,242,1) 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,1)), color-stop(100%,rgba(242,242,242,1))); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(242,242,242,1) 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(242,242,242,1) 100%); /* Opera 11.10+ */
    background: -ms-linear-gradient(top, rgba(255,255,255,1) 0%,rgba(242,242,242,1) 100%); /* IE10+ */
    background: linear-gradient(to bottom, rgba(255,255,255,1) 0%,rgba(242,242,242,1) 100%); /* W3C */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#f2f2f2',GradientType=0 ); /* IE6-9 */
}

.call-to-action-box {
    background: #27282B;
    border: solid 1px #404040;
}

.call-to-action-box .inner {
padding: 20px 20px 20px 20px;
}

.call-to-action-box .text {
margin-right: 20px;
float: left;
}

.call-to-action-box .act {
float: right;
}

.call-to-action-box h3 {
margin: 0;
margin-top:10px;
}

.call-to-action-box .btn{
color:#eceff3;
}

.call-to-action-box{
background: #404040;
color:#eceff3;
}

.call-to-action-boxh3 {
color:#eceff3;
}

/* ================================================== */
/* overide bootstrap */
/* ================================================== */
.btn-primary{
    text-shadow: none;
    border: none ;
}

.btn.btn-primary:hover{
background:#555;
}

.img-responsive {
  display: inline-block;
}

.label {
    font-family: "Roboto",Arial, Helvetica, sans-serif;
}

table thead {
    font-weight: bold;
}

.accordion-heading a {
    text-decoration: none;
    border: none;
    outline: none;
}

p.lead, p.intro {
  font-size: 16px;
  font-weight: 500;
  line-height: 1.7em;
}

.panel-group{
    opacity:.8;
}

.panel-heading,.panel-body{
    background:#27282B;
    border:solid 1px #404040 ;
    border-radius:0 ;
}

.panel-body{
    border-top:none ;
}

.progress{
    background:#27282B;
}

.panel-heading h4 a{
    display:block;
}

.panel-heading h4 a:hover{
    color:#eceff3;
}

.panel-default, .panel-collapse, .panel-collapse, .panel-group .panel {
    border:none ;
    border-radius:0 ;
}

.panel-heading{
    background:#222 ;
}

.table-bordered, .table-bordered td{
    border:solid 1px #404040;
}

blockquote {
    font-size: 24px;
    font-style: italic;
    line-height: 1.5em;
    font-weight: 300;
}
.post-text blockquote {
    margin: 20px 0 20px 36px;
    font-size: 13px;
    padding: 5px 20px 5px 20px;
    font-weight: normal;
}
blockquote span {
    display: block;
    font-size: 14px;
    font-style: normal;
    font-weight: normal;
}
.col-md-3{
    margin-right:-1px;
}
.no-padd .col-md-12{
    padding-left:0;
    padding-right: 0; 
}
.no-padd .row{
    margin-right:0;
    margin-left: 0;
}
.padding-top-bottom{
    padding-top: 90px;    
}
.padding-top-90{
    padding-top:90px;
}
h3 b{
    font-size: 18px;
    letter-spacing: 3px;
    text-transform: uppercase;
    font-weight: 400;
}

.menu-sidebar-menu-container{
    visibility: visible;
    animation-name: fadeInUp;
    padding-left: 5px;
}
#menu-sidebar-menu{
    margin: 0;
    padding: 0;
}
.menu-sidebar-menu-container ul li{
    font-weight: bold;
    list-style: none;
    margin: 0;
    background: rgba(0,0,0,.3);
    margin-bottom: 10px;
}
.menu-sidebar-menu-container ul li a{
    display: block;
    padding: 20px;
    text-decoration: none;
} 
.menu-sidebar-menu-container ul li.current_page_item a  {
    color: #000;
}
.tp-bannershadow,.tp-bullets{
    display: none;
}
ul.countdown {
    position: relative;
    width: 100%;
    display: block;
    text-align: center;
}
ul.countdown li {
    display: inline-block;
}
ul.countdown li span {
    font-size: 72px;
    line-height: 80px;
    
    color: #fff;
}
ul.countdown li p {
    color: rgba(255,255,255,.8);
    font-size: 14px;
    text-transform: uppercase;
    letter-spacing: 3px;
    margin-top: 20px;
}
ul.countdown li.seperator {
    font-size: 40px;
    width: 40px;
    text-align: center;
    line-height: 80px;
    vertical-align: top;
    padding-left: 40px;
    padding-right: 40px;
    color: #fff;
    font-family: 'big-john';
}
.project-view section.bg-fixed{
    background: transparent;
}
.project-info{
    color:#ccc;
    margin-left:20px;
}
.project-info h2{
    margin-top: 0;
    font-size:18px;
    letter-spacing:3px;
    text-transform:uppercase;
}
.project-info h4{
    font-weight:bold;
}
.project-info .details{
    padding:20px;
    border:solid 1px rgba(255,255,255,.2);
    background:rgba(0,0,0,.5);
    margin-bottom:30px;
}
.project-infoproject-info span{
    display:block;
}
.project-info span.title{
    display:inline-block;
    min-width:80px;
}
.project-info span.val{
    margin-bottom:15px;
    font-weight:bold;
}
.project-view{
    padding:120px 0 80px 0;
}
.project-images img{
    width:100%;
}
/* ================================================== */
/* image position */
/* ================================================== */
.img-left {
    float: left;
    margin: 5px 15px 15px 0;
}
.img-right {
    float: right;
    margin: 5px 0 15px 15px;
}

/* ================================================== */
/* flickr */
/* ================================================== */
#flickr-photo-stream img {
    width: 48px;
    height: auto;
    margin: 0 12px 12px 0;
    float: left;
}
#flickr-photo-stream a img {
    border: solid 2px #fff;
}
#flickr-photo-stream a:hover img {
    border: solid 2px #777777;
}
hr{
    border-top: solid 1px #555;
}
hr.blank {
    border: none;
    margin: 20px 0 20px 0;
}
/* ================================================== */
/* font awesome icons */
/* ================================================== */
i {
    display: inline-block;
    float: left;
    margin-right: 10px;
    margin-bottom: 5px;
}
i.large {
    font-size: 40px;
    padding: 16px;
    width: 40px;
    height: 40px;
    text-align: center;
}
.landing-download  i.large {
    font-size: 72px;
    text-align: center;
    display:inline-block;
    float:none;
    padding: 0px;
    width: auto;
    height: auto;
}
i.medium {
    font-size: 20px;
    padding: 10px;
    width: 20px;
    height: 20px;
    text-align: center;
}
i.small {
    font-size: 12px;
    padding: 4px;
    width: 16px;
    height: 15px;
    text-align: center;
}
i.circle-icon {
    border-radius: 75px;
    -moz-border-radius: 75px;
    -webkit-border-radius: 75px;
}
/* extra ^ */
.de_center p {
    width: 100%;
}
.de_center .de_icon {
    float: none;
    margin: 0 auto;
}

/* ================================================== */
/* transition */
/* ================================================== */
a,
a:hover,
.test-column,
.test-column:hover {
    -o-transition: .3s;
    -ms-transition: .3s;
    -moz-transition: .3s;
    -webkit-transition: .3s;
    transition: .3s;
}
.de_contact_info{
    font-size:40px;
    font-weight:bold;
}
.de_contact_info i{
    float:none;
    margin-right:20px;
}
.center-div{
    margin:0 auto ;
}
#portfolio-controls {
    background: #111111;
    height: 50px;
    overflow: hidden;
    position: relative;
    width: 100%;
    z-index: 2;
}
.left-right-portfolio {
    float: left;
    height: 50px;
    overflow: hidden;
    position: relative;
    transition: all 300ms linear 0s;
    width: 40%;
    z-index: 2;
}
.center-portfolio {
    background: #0B0B0B;
    float: left;
    height: 50px;
    overflow: hidden;
    position: relative;
    transition: all 300ms linear 0s;
    width: 20%;
    z-index: 2;
}
.portfolio-icon {
    font-family: "FontAwesome";
    font-size: 20px;
    line-height: 50px;
    text-align: center;
    width: 100%;
    color: #fafafa;
}
.portfolio-icon a {
    display: block;    
}
.portfolio-icon a:hover, .center-portfolio:hover{background: rgba(230, 230, 230, 1) none repeat scroll 0 0;}
.portfolio-icon a i {float: none;color: #fafafa;}
.portfolio-navigation {}
.portfolio-navigation .portfolio-btn-prev {width: 50%;float: left;}
.portfolio-navigation .portfolio-btn-next {text-align: right;width: 50%;float: right;}
.portfolio-navigation a {
    display: inline-block;    
    border:1px solid #dddddd;
    color: #dddddd;
    background-color: transparent;
    padding-left: 3px;
    padding-right: 14px;
    letter-spacing: 0.05em;
    height: 30px;
    line-height: 30px;
    font-size: 14px;
    padding: 0px 16px 0px 14px;
    text-decoration: none;
    text-transform: uppercase;
    -webkit-transition: all .2s ease-in-out;
    -moz-transition: all .2s ease-in-out;
    -o-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
}
.portfolio-navigation a i {
    float: none;
    margin: 0px;
    color: #FAB702;
    -webkit-transition: all .2s ease-in-out;
    -moz-transition: all .2s ease-in-out;
    -o-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
}
.portfolio-navigation a:hover{background-color: #FAB702;color: #333;}
.portfolio-navigation a:hover i{
    color: #333;
}
.socials-portfolio {margin-top: 30px;}
.socials-portfolio h4 {display: inline-block;}
.socials-sharing {display: inline-block;}
.socials-sharing a.socials-item {
    display: inline-block;
    width: 30px;
    height: 30px;
    line-height: 30px;
    text-align: center;
    border-radius: 50%;
    border:1px solid #888;
    margin-left: 5px;
    margin-top: 10px;
    margin-bottom: 10px;
    -webkit-transition: all .2s ease-in-out;
    -moz-transition: all .2s ease-in-out;
    -o-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
}
.socials-sharing a.socials-item i {
    float: none;margin: 0px;
}
/* Portfolio Style 2 */
.folio-style2 .folio-info {padding: 10px 0;}
.folio-style2 a {text-decoration: none;}
.folio-style2 h3:hover{text-decoration: underline;}
.folio-style2 .folio-info h3{
    font-size: 18px;
    margin-top: 10px;
    margin-bottom: 5px;
    font-weight: 300;
}
.folio-style2 .folio-info p {
    font-size: 14px;
    color: #999999;
}
.folio-style2 .folio-image img {max-width: 100%;height: auto;}
.folio-style2 .folio-info p span{
    display: inline-block;
    margin-left: 4px;
    margin-right: 2px;
}
.folio-style2 .folio-info p span:last-child{display: none;}

/* ---- grid ---- */
.grid {
    width:100%;
}

/* clear fix */
.grid:after {
    content: '';
    display: block;
    clear: both;
}
/* ---- .element-item ---- */

/* 5 columns, percentage width */
.grid-sizer {
    width: 5%;
}
.grid-item {
    float: left;
    border:none;
    overflow:hidden;
    margin:0;
    padding:0;
}
.large-width {width: 50%;}

@media only screen and (max-width : 768px) {
  .w1, .w2, .w3, .w4, .w5 {width:100%}
}

/* ================================================== */
/* widget */
/* ================================================== */
#sidebar{
    padding-left:20px;
}
.sidebar-left #sidebar{
    padding-left:0px;
    padding-right: 20px;
}
.widget {
    margin-bottom: 60px;
    padding-bottom:60px;
    border-bottom:solid 1px #333;
}
.widget h4 {
    text-transform:uppercase;
    padding-bottom: 20px;
    font-size: 16px;
    letter-spacing: normal;
    letter-spacing:1px;
}
.widget ul {
    list-style: none;
    margin: 0;
    padding:0;
}
.widget  .small-border{
    height:2px;
    width:30px;
    background:#fff;
    margin:10px 0 20px 0;
    display:block;
}
.widget_category li {
    padding: 8px 20px 8px 20px;
    margin-bottom: 8px;
    background:#111;
    text-transform:uppercase;
}
.widget_category li a {
    color:#606060;
}
.widget_recent_post li {
    padding-left: 20px;
    background: url(images/list-arrow.png) left 2px no-repeat;
    border-bottom: solid 1px #222;
    padding-bottom: 7px;
    margin-bottom: 5px;
}
.widget_recent_post li a {
    color: #555;
}
.widget .comments li {
    padding-left: 20px;
    background: url(images/list-arrow.png) left 2px no-repeat;
    border-bottom: solid 1px #eee;
    padding-bottom: 7px;
    margin-bottom: 5px;
}
.widget_tags li {
    text-shadow:none;
    display: inline-block;
    margin-right: 2px;
    margin-bottom: 13px;
}
.widget_tags li a {
    font-size:12px;
    text-decoration: none;
    margin-bottom: 5px;
    border-radius: 1px;
    -moz-border-radius: 1px;
    -webkit-border-radius: 1px;
    border:solid 1px rgba(255,255,255,.1);
    color: #888;
    padding: 5px 8px 5px 8px;
}
.widget_tags li a:hover {
    color:#555;
    border-color: #555;
}

.widget_tags li a{
    border-color:#555;
}

.widget_tags li a:hover {
    color:#eceff3;
    border-color:#eceff3;
}
.search-form {
    position: relative;
}
.search-form:before {
    content: '\f002';
    font-family: FontAwesome;
    color: #F86E4E;
    position: absolute;
    top: 0;
    right: 0;
    font-size: 14px;
    width: 33px;
    height: 33px;
    line-height: 33px;
    text-align: center;
    cursor: pointer;
}
.search-form input[type=text] {
    border: 1px solid #E4DBDB;
    padding: 10px;
    background: #fff;
    border-radius: 4px;
    width: 100%;
    height: 32px;
    font-weight: 400;
    padding-right: 36px;
    box-sizing: border-box;
    color: #000;
}
.search-form input[type=text]:focus{
    box-shadow: none;
}
.search-form .submit-search {
    width: 35px;
    height: 32px;
    background: transparent;
    position: absolute;
    top: 0;
    right: 0;
    border: none;
    text-indent: -9999px;
}
.widget_tag_cloud li {
    display: inline-block;
    margin-right: 2px;
    margin-bottom: 13px;
}
.widget_tag_cloud li a {
    font-size: 13px;
    text-decoration: none;
    margin-bottom: 5px;
    border: solid 1px rgba(255,255,255,.1);
    -moz-border-radius: 1px;
    -webkit-border-radius: 1px;  
    padding: 5px 8px 5px 8px;
}
.widget_tag_cloud li a:hover{
    border-color: #fff;
    color:#fff;
}
.widget_flickr a img{
    float:left;
}
.widget_recent_comments .comment-author-link{
    font-weight: 600;
    color: #fff;
    font-size: 14px;
}
table {
    border-collapse: separate;
    border-spacing: 0;
    border-width: 1px 0 0 1px;
    margin-bottom: 24px;
    width: 100%;
}
table, th, td {
    border: 1px solid #333;
}
#wp-calendar caption {
    background: none repeat scroll 0 0 #333;
    color: #fff;
    font-size: 16px;
    padding: 10px 0;
    text-align: center;
}
#wp-calendar thead {
    font-size: 10px;
}
table thead {
    font-weight: bold;
}
#wp-calendar thead th {
    border-color: #333;
    border-bottom-style: solid;
    font-size: 13px;
    padding: 8px 0;
    text-align: center;
    vertical-align: middle;
}
th {
    border-width: 0 1px 1px 0;
    font-weight: bold;
}
#wp-calendar tfoot #prev {
    font-size: 12px;
    text-transform: uppercase;
    padding-top: 10px;
    color: #37c878;
}
td {
    border-width: 0 1px 1px 0;
}
#wp-calendar tbody td {
    border-color: #333;
    border-bottom-style: solid;
    text-align: center;
    padding: 8px;
}
#wp-calendar tbody td:hover{
    background: #333;
}
footer .widget{
    border:none;
    margin-bottom:0;
}
.widget_tags ul{
    margin-top:30px;
}
footer .widget.widget_tags li a{
    border-color:#222;
}
footer .widget_recent_entries li, footer .widget_archive li,
footer .widget_categories li, footer .widget_nav_menu li, 
footer .widget_pages li, footer .widget_meta li {
    padding: 0 0 5px 0;
    margin:0;
    background: none;
    border-bottom: solid 1px #222;
    border-bottom-color:#222;    
}
footer .widget_recent_entries li a, footer .widget_archive li a,
footer .widget_categories li a, footer .widget_nav_menu li a, 
footer .widget_pages li a, footer .widget_meta li a {
    color: #ccc;    
}
footer .widget h3{
    margin-bottom:20px;
}

/*-----------------------------------------------------------------------------------*/
/*  STYLES WIDGET
/*-----------------------------------------------------------------------------------*/ 
    .widget select {max-width: 100%;padding: 5px;border: 1px solid #ccc; width: 100%;}
    .widget_text .textwidget img{max-width: 100%;height: auto;}
    .widget_text select, .widget_text input , .widget_text textarea  {max-width: 100%;padding: 5px;border: 1px solid #ccc; width: 100%;}
    .widget_text option {max-width: 100%;}
    .widget_archive ul li {margin-bottom: 10px;}
    .widget_nav_menu ul li, .widget_pages ul li { 
        color: #827b7d;
        line-height: 20px;
        margin-bottom: 10px;
   }
  .widget_recent_comments ul li {margin-bottom: 10px;}
  .text-post ul, .content-page ul {padding-left: 20px;list-style: disc outside none; }
  .text-post ul li, .content-page ul li {list-style: disc outside none; }
  .text-post ol, .content-page ol {padding-left: 20px;list-style: decimal outside none; }
  .text-post ol  li, .content-page ol li {list-style: decimal outside none;}
  .magnis-widget select {width: 100%; max-width: 100%; padding: 4px;}
  .widget_nav_menu ul ul {margin-left: 25px;margin-top: 0px;}
  .widget_rss ul li {margin-bottom: 15px;}
  .widget_rss ul li a.rsswidget {display: block;}
  .rssSummary {line-height: 24px;}
  .rss-date {font-style: italic;}
  .dotted-widget select {width: 100%;padding: 5px 0px;}
  .page-content ul, .page-content ol {float: none;margin-top: 0;padding-left: 40px;}
  .page-content ul li {
    list-style: inherit;
    line-height: 28px;
    margin-bottom: 0px;
    padding-bottom: 0px;
    border: none;
  }
  blockquote cite, p cite {color: #fff;}  
  .page-content ol li {line-height: 28px;list-style: decimal;margin-bottom: 0px;padding-bottom: 0px;border: none;}
  .page-content ol ol, .page-content ul ul {margin-bottom: 0px;padding-bottom: 0px;}
  .page-content h6 {color: #fff;}.page-content h1 {text-align: left;}
  .widget_categories ul ul.children, .widget_pages ul ul.children {padding-left: 20px;}
  .widget_categories ul ul.children li:last-child, .widget_pages ul ul.children li:last-child {margin-bottom: 0px;}
  .page .leave-reply {margin-left: 0px;}
  /* Sticky post */
  .sticky .post-text.post-text-no-image {background: none repeat scroll 0 0 #ddd;padding: 20px;}
  .sticky.post-item .post-item-body .meta {margin-top: 0px ;padding: 10px 15px;background: #ececec;}
  .sticky.post-item .post-item-body .meta p {margin-right: 20px;margin-top: 0px;}

   /* Pagination Comment */  
   .nav-links .nav-previous {float: left;}
   .navigation.comment-navigation .nav-next, .nav-links .nav-next {float: right;}
   .navigation.comment-navigation .nav-next:before, .nav-links .nav-next:before {
        color: #fff;
        content: "";
        cursor: pointer;
        font-family: "FontAwesome";
        font-size: 1px;
        padding: 0px;
   }
   .sidebar .widget_recent_entries ul li {margin-bottom: 5px;}
/**** End STYLE CSS For WIDGET ****/ 

/* ================================================== */
/* misc */
/* ================================================== */
a{
    color:#fff;
    text-decoration:none;
}
a:hover{
    color:#fff;
}
.fontsize24{font-size:24px ;}
.fontsize32{font-size:32px ;}
.fontsize36{font-size:36px ;}
.fontsize40{font-size:40px ;}
.fontsize48{font-size:48px ;}
.padding10{padding:10px ;}
.padding20{padding:20px ;}
.padding30{padding:30px ;}
.padding40{padding:40px ;}
.padding50{padding:50px ;}
.padding60{padding:60px ;}
.margintop20{margin-top: 20px;}
.padding80{padding:80px ;}
.padtop80{padding-top: 80px;}
.padbottom80{padding-bottom: 80px;}
.padtop0 {padding-top: 0px !important;}
#services-list{padding:0;margin:0;}
#services-list li{
    font-weight:bold;
    list-style:none;
    margin:0;
    margin-bottom:10px;
}
#services-list li a{
    color:#fff;
    display:block;
    padding:20px;
    text-decoration:none;
    background:rgba(0,0,0,.3);
}
#services-list li a:hover{
    color:#111;
}
.pic-services img{
    margin-bottom:30px;
}
#services-list li.active a, #services-list .widget_nav_menu ul.menu > li.current-menu-item > a, #services-list > li.current-menu-item > a, 
#services-list li li.current-menu-item > a {
    color:#111;
}
#services-list .widget {margin-bottom: 0px;padding-bottom: 0px;border-bottom-width: 0px;}
#services-list li ul {
    padding-top: 10px;
}
.services-masonry .item, .item-service {margin-bottom: 60px ;}
.service-list:nth-child(2n-1){
    background-color: #202224;
}
.service-list p {margin-bottom: 0px;}
.service-grid h3 a {text-decoration: none;}
.project-images img {margin-bottom:60px;}
.teaser-text{
    font-size:14px;
    color:rgba(255,255,255,.5);
    line-height:normal;
    font-weight:300;
    text-transform:uppercase;
    letter-spacing:6px;
}
.teaser-text-2{font-size:16px;}
#navigation{
	position:fixed;
	width:100%;
	height:60px;
	top:0;
	right:20px;
	text-align:center;
	margin-bottom:60px;
	z-index:1000;
}
.mfp-close{
	color:#fff !important;
	position:absolute;
	left:50%;
	width:100%;
	font-size:48px !important;
	margin-top:40px;
	margin-left: -22px;
	z-index:1000;
}
.nav-prev:before,.nav-next:before, .nav-exit:before{
    font-family:"FontAwesome";
    content:'\f177';
    color:#fff;
    padding:20px;
    font-size:24px;
    cursor:pointer;
}
.nav-exit:before{
    width:100%;
    display:block;
}
.nav-next:before{
    content:'\f178';
    width:100%;
    background:#555;
}
.nav-exit:before{
    content:'\f00d';
}
.container-3 .de-team-list{
    width:33.333333%;
    float:left;
    position:relative;
}
.container-4 .de-team-list{
    width:24.9%;
    float:left;
    position:relative;
}
.container-5 .de-team-list{
    width:19.9%;
    float:left;
    position:relative;
}
.no-top {
    padding-top: 0 ;
}
.no-bottom {
    padding-bottom: 0 ;
}
.no-bottom{
    margin-bottom:0;
    padding-bottom:0;
}
p{
    margin-bottom:20px;
}
strong.intro{
    font-size:16px;
    line-height:1.5em;
    font-weight: normal;
}
.bg-grey{
    background:#f5f5f5;
}
.no-bottom {
    padding-bottom: 0 ;
}
.no-top {
    padding-top: 0 ;
}
.bg-side{
    position:relative;
    overflow:hidden ;
}
.image-container{
    position:absolute;
    padding:0;
    margin:0 ;
    background-size:cover ;
}
.side-bg {position: relative;}
.side-bg .background-image {
    background-position: 50% 50% ;
    background-size: cover ;
    height: 100%;
    left: 0;
    position: absolute;
    width: 100%;
    z-index: 0;
}
.side-bg .image-container {
    height: 100%;
    overflow: hidden;
    padding: 0;
    position: absolute;
    top: 0;
}
.right0 {right: 0px;}

.image-slider{
    cursor:move;
}
.inner-padding{
    padding:90px 0 90px 0;
}
.no-padding{
    padding:0;
}
#content.no-padding{
    padding:0;
}
.float-left {
    float: left;
}
#loader-area{
    display:none;
    background:#fff;
}
#loader-area{
    display:none;
    background:#111;
}
.loader {
    position: fixed;
    left: 0px;
    top: 0px;
    width: 100%;
    height: 100%;
    z-index: 99999;
    background: url('.images/page-loader.gif') 50% 50% no-repeat rgb(249,249,249);
}
.page-overlay {
    display:none;
    width: 120px;
    height: 120px;
    background:url(images/page-loader.gif) center no-repeat #fff;
    border-radius:10px;
    position: fixed;
    top:0;
    bottom: 0;
    left: 0;
    right: 0;
    z-index:10000;
    margin: auto;
}
.teaser{
    font-family: 'Raleway', Arial, sans-serif;
    font-size:15px;
    font-weight:300;
}
span.teaser {
    font-family: "Georgia";
    font-size: 18px;
    font-style: italic;
}
.form-control:focus{
    box-shadow:none;
    -moz-box-shadow:none;
    -webkit-box-shadow:none;
}
.owl-arrow{
    position:absolute;
    z-index:100;
    background:#fff;
    margin-top:48%;
    display:none;
    cursor:pointer;
}
.owl-arrow span{
    display:block;
    background:#555;
    position:absolute;
    
}
.owl-arrow .prev{
    left:0;
}
.owl-arrow .next{
    right:0;
}

.owl-arrow .prev:before, .owl-arrow .next:before{
    font-family:"FontAwesome";
    content:'\f177';
    color:#fff;
    padding:20px;
    font-size:32px;
    display:block;
}
.owl-arrow .next:before{
    content:'\f178';
}

.owl-theme .owl-controls .owl-page span{
    width: 7px;
    height: 7px;
}

.owl-pagination{
    margin-top: 10px;
}

.owl-custom-nav{
    position:absolute;
    z-index:1000;
    width:100%;
}
.owl-custom-nav .btn-next{
    position:absolute;
    right:0;
}
.owl-custom-nav .btn-prev{
    position:absolute;
    left:0;
}
.owl-custom-nav .btn-next:before{
    font-family:"FontAwesome";
    content:"\f105";
    color:#111;
    background:#333;
    padding:5px 12px 5px 12px;
    font-size:20px;
}
.owl-custom-nav .btn-prev:before{
    font-family:"FontAwesome";
    content:"\f104";
    color:#111;
    background:#333;
    padding:5px 12px 5px 12px;
    font-size:20px;
}
.owl-custom-nav a{
    text-decoration:none;
}
.owl-custom-nav .btn-prev:hover:before,
.owl-custom-nav .btn-next:hover:before{
    cursor:pointer;
    background:#111;
    color:#fff;
}
.owl-theme .owl-controls .owl-buttons div{
    background:#ffffff;
    opacity:1;
    border-radius:3px;
    -moz-border-radius:3px;
    -webkit-border-radius:3px;
    padding-top:0px;
    height:32px;
    margin-top:20px;
    color:#111111;
    text-transform:uppercase;
    letter-spacing:5px;
}
.owl-theme .owl-controls .owl-buttons div:hover{
    opacity:.8 !important;
    color: #fff;
}
.owl-theme .owl-controls .owl-buttons .owl-prev:before{
    font-family:"FontAwesome";
    content:"\f104";
    padding:5px 12px 5px 12px;
    font-size:24px;
    position:relative;
}
.owl-theme .owl-controls .owl-buttons .owl-next:after{
    font-family:"FontAwesome";
    content:"\f105";
    padding:5px 12px 5px 12px;
    font-size:24px;
    position:relative;
}
.post-image .owl-theme .owl-controls .owl-page span{
    width:10px ;
    height:10px ;
}
.gallery-carousel.owl-theme .owl-controls .owl-buttons div{
    margin-left: 0px;
    margin-right: 0px;
    border-radius: 0px;
}
.gallery-carousel .owl-buttons .owl-prev:hover,
.gallery-carousel .owl-buttons .owl-next:hover{
    cursor:pointer;
    background:#111;
    color:#fff;
}
.text-slider{
    line-height:72px;
    color:#fff;
    font-size:72px;
    text-transform:uppercase;
    font-weight:300;
    display:inline-block;
    letter-spacing:20px;
}
.text-slider.big-text{
    font-size:120px;
    line-height:120px;
    font-weight:bold;
}
.border-deco .text-item{
    display:inline-block;
}
.text-item i{
    font-size:60px;
    margin-top:5px;
}
.text-slider.big-text i{
    font-size:90px;
    margin-top:15px;
}

.fontsize40 .text-slider{font-size: 40px !important;}
.text-dark .text-slider{color: #222;}

/* mouse scroll icon begin */
.mouse {
  position: absolute;
  width: 22px;
  height: 42px;
  bottom: 40px;
  left: 50%;
  margin-left: -12px;
  border-radius: 15px;
  border: 2px solid #888;
  -webkit-animation: intro 1s;
  animation: intro 1s;
}
.scroll {
  display: block;
  width: 3px;
  height: 3px;
  margin: 6px auto;
  border-radius: 4px;
  background: #888;
  -webkit-animation: finger 1s infinite;
  animation: finger 1s infinite;
}
@-webkit-keyframes intro {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    transform: translateY(0);
  }
}
@keyframes intro {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px);
  }
  100% {
    opacity: 1;
    -webkit-transform: translateY(0);
    transform: translateY(0);
  }
}
@-webkit-keyframes finger {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(20px);
    transform: translateY(20px);
  }
}
@keyframes finger {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
    -webkit-transform: translateY(20px);
    transform: translateY(20px);
  }
}
/* mouse scroll icon close */

/* ================================================== */
/* quick-search */
/* ================================================== */
.quick-search {
    display: inline-block;
    float: right;
    margin-left: 10px;
    padding: 10px 0 0 0;
}
.quick-search input {
    width: 120px;
    border-radius: 40px;
}  
#search, .woocommerce .woo-search-field{
    float:left;
    width: -webkit-calc(100% - 50px);
    width: expression(100% - 50px);
    width: -moz-calc(100% - 50px);
    width: -o-calc(100% - 50px);
    width: calc(100% - 50px);
    margin-bottom:0;
    height: 42px;
    line-height: 42px;
}
#btn-search{
    border:none;
    padding: 7px 7px 7px 7px;
    background: #222;
    float: left;
    width: 50px;
    height: 42px;
}
#btn-search:before{
    font-family: FontAwesome;
    content: "\f002";
    font-size: 24px;
    color: #111;
}
#btn-search:hover{
    background: #fff;
}

/* ================================================== */
/* review */
/* ================================================== */
.de_review {
    text-align:center;
    min-height:260px;
}

.de_review .de_nav {
    overflow: hidden;
    padding-left: 0;
    margin: 0;
    padding: 0;
    font-weight:bold;
    text-align:center;
}

.de_review .de_nav li {
    list-style: none;
    background: #EEE;
    margin: 0 10px 0 10px;
    margin-bottom:20px;
}

.de_review .de_nav li{
    display:inline-block;
}

.de_review .de_nav li img{
    width:100px;
    height:auto;
}

.de_review .de_nav li span {
    padding: 8px 16px 8px 16px;
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
    border-left: 1px solid #ddd;
    border-right: 1px solid #ddd;
    display: block;
    background: #f5f5f5;
    text-decoration: none;
    color: #646464;
    font-size: 13px;
    cursor: pointer;
}

.de_review blockquote{
    border:none;
    font-family:"Roboto Slab", Georgia, "Times New Roman", Times, serif;
}

.de_review .de_nav li span {
    border: 1px solid #404040;
    background:#222;
}

.de_review .de_nav li:first-child span {
    border-left: 1px solid #ddd;
}

.de_review .de_nav li:first-child span {
    border-left: 1px solid #404040;
}

.de_review .de_review_content {
    border: 1px solid #ddd;
    padding: 15px 20px 20px 20px;
    margin-top: -1px;
    background: #fff;
}

.de_review .de_review_content {
    border: 1px solid #404040;
    background: #27282b;
}

.de_review .de_nav li.active span {
    background: #FFF;
    border-bottom: 1px solid #fff;
    color: #222;
    margin-bottom: -3px;
}
.separator {
  line-height: 0.5;
  text-align: center;
  margin:30px 0 30px 0;
}
.separator span {
  display: inline-block;
  position: relative;
 
}
.separator span:before,
.separator span:after {
  content: "";
  position: absolute;
  border-bottom: 1px solid rgba(255,255,255,.1);
  top: 5px;
  width: 300px;
}
.separator span:before {
  right: 100%;
  margin-right: 15px;
}
.separator span:after {
  left: 100%;
  margin-left: 15px;
}
.separator span  i{
    font-size:6px;
    padding:0;
    margin:0;
    float:none;
}
.text-light .separator span:before,
.text-light .separator span:after {
  border-bottom: 1px solid rgba(255,255,255,.1);
}
.line-light.separator span:before, .line-light.separator span:after {border-bottom: 1px solid rgba(255,255,255,.1);}
.line-dark.separator span:before, .line-dark.separator span:after {border-bottom: 1px solid rgba(0,0,0,.2);}

.title_404{
  font-size: 50px;
  font-weight: 400;
  margin-bottom: 20px;
}
.content_404{
    margin-bottom: 20px;
}

/* css attributes */

/* margin top */
.mt0{margin-top:0;}.mt10{margin-top:10px;}.mt20{margin-top:20px;}.mt30{margin-top:30px;}.mt40{margin-top:40px;}.mt50{margin-top:50px;}.mt60{margin-top:60px;}.mt70{margin-top:70px;}.mt80{margin-top:80px;}.mt90{margin-top:90px;}.mt100{margin-top:100px;}
/* margin bottom */
.mb0{margin-bottom:0;}.mb10{margin-bottom:10px;}.mb20{margin-bottom:20px;}.mb30{margin-bottom:30px;}.mb40{margin-bottom:40px;}.mb50{margin-bottom:50px;}.mb60{margin-bottom:60px;}.mb70{margin-bottom:70px;}.mb80{margin-bottom:80px;}.mb90{margin-bottom:90px;}.mb100{margin-bottom:100px;}
.pt0{padding-top:0;} .pt10{padding-top:10px;} .pt20{padding-top:20px;} .pt30{padding-top:30px;} .pt40{padding-top:40px;} .pt80{padding-top:80px;}
.pb0{padding-bottom:0;} .pb10{padding-bottom:10px;} .pb20{padding-bottom:20px;} .pb30{padding-bottom:30px;} .pb40{padding-bottom:40px;} .pb80{padding-bottom:80px;}
.mr10{margin-right:10px;}.mr20{margin-right:20px;}.mr30{margin-right:30px;} 

/* margin top */
.mt-10{margin-top:-10px;}.mt-20{margin-top:-20px;}.mt-30{margin-top:-30px;}.mt-40{margin-top:-40px;}.mt-50{margin-top:-50px;}.mt-60{margin-top:-60px;}.mt-70{margin-top:-70px;}.mt-80{margin-top:-80px;}.mt-90{margin-top:-90px;}.mt-100{margin-top:-100px;}
.absolute{position:absolute; z-index:1;}
.overflow-hidden{overflow:hidden;}
.width100{width:100%;}
.border1{border-width:1px ;}
.display-table{
    display:table;
    margin-right: -1px;
}
.display-table [class*="col-"] {
    float: none;
    display: table-cell;
    vertical-align: top;
    margin:0;
    padding:0;
}
.text-middle, .display-table [class*="col-"].text-middle {
    vertical-align: middle;
}
.text-bottom, .display-table [class*="col-"].text-bottom {
    vertical-align: bottom;
}
.overlay50{background:rgba(0,0,0,.5)}
.overlay60{background:rgba(0,0,0,.6)}
.overlay70{background:rgba(0,0,0,.7)}
.overlay80{background:rgba(0,0,0,.8)}
.display-table  .z-index-2{position: relative;z-index: 2;}

.display-table .mask-overlay {
    position: absolute;
    top:0;
    left:0; 
    width: 100%;
    height:100%;
    z-index:1;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background:rgba(0,0,0,.7);
}

/* columns */
.fullwidth {
    display: table;
    width: 100%;
    table-layout: fixed;
    border-collapse: collapse;
    padding: 0 ;
    margin: 0 ;
    overflow: hidden;
}

.box-container {
    width: 101%;
}

.one-fourth {
    width: 24.9%;
    display: table-cell;
    vertical-align: middle;
}

.one-third {
    width: 33.3%;
    float: left;
}

.three-fourth {
    width: 74.9%;
    height: 100%;
    display: table-cell;
}

.box-one-third {
    width: 33.333%;
    float: left;
}
.box-four-columns {
    width: 25%;
    float: left;
}
.box-five-columns {
    width: 20%;
    float: left;
}
.box-six-columns {
    width: 16.66666667%;
    float: left;
}
.box-two-columns {
    width: 50%;
    float: left;
}

/* Styling Next and Prev buttons */
.owl-theme .owl-controls .owl-buttons div {
  color: #222;
  display: inline-block;
  zoom: 1;
  *display: inline;
  /*IE7 life-saver */
  margin: 0px;
  padding: 0px 0px;
  width: 32px;
  height: 32px;
  line-height: 32px;
  text-align: center;
  font-size: 18px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  margin: 0px 10px;
  transition: opacity 0.2s ease-out 0s;
  filter: alpha(opacity=80);
  /*IE7 fix*/
  opacity: 0.8;

}
.owl-theme .owl-controls .owl-buttons div i{float: none;margin: 0px;}
/* Clickable class fix problem with hover on touch devices */
/* Use it for non-touch hover action */
.owl-theme .owl-controls.clickable .owl-buttons div:hover {
  text-decoration: none;
  filter: alpha(opacity=100);
  /*IE7 fix*/
  opacity: 1;
}
.owl-theme .owl-controls .owl-buttons {
    width: 100%;
}
.owl-theme .owl-controls .owl-buttons .owl-prev{
    position: absolute;
    top: 50%;
    left: 0px;
    margin-top: -16px;
}
.owl-theme .owl-controls .owl-buttons .owl-next {
    position: absolute;
    top: 50%;
    right: 0px;
    margin-top: -16px;
}

.before-after-slider.owl-theme .owl-controls .owl-buttons {
    position: static;
    margin: 0px;
    width: auto;
}
.before-after-slider.owl-theme .owl-controls .owl-buttons .owl-prev, 
.before-after-slider.owl-theme .owl-controls .owl-buttons .owl-next{
    float: none;
    width: auto;
    opacity: 1;
    padding: 0px 10px;
    margin: 5px;
    margin-top: 20px;
    line-height: inherit;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    height: 32px;
	line-height: 23px;
    margin-top: 20px;
    color: #111111;
    text-transform: uppercase;
    letter-spacing: 5px;
    font-size: inherit;
    position: static;
}
.before-after-slider.owl-theme .owl-controls .owl-buttons .owl-next:after {
    top: 4px;
    right: -15px;
}
.before-after-slider.owl-theme .owl-controls .owl-buttons .owl-prev:before{
    top: 4px;
    left: -10px;
}

/* Back To Top*/
#back-to-top {
    background: #f5f5f5;
    border: 0 none;
    border-radius: 2px;
    bottom: 40px;
    cursor: pointer;
    height: 32px;
    line-height: 30px;
    opacity: 0;
    outline: medium none;
    position: fixed;
    right: 40px;
    text-align: center;
    text-decoration: none;
    transition: opacity 0.2s ease-out 0s;
    width: 32px;
    z-index: 1000;
}
#back-to-top:hover {
    background: #000 none repeat scroll 0 0;
}
#back-to-top.show {
    opacity: 1;
}
#back-to-top:before {
    color: #222;
    content: "\f106";
    font-family: "FontAwesome";
    font-size: 22px;
    margin: 5px;
    position: relative;
}
#back-to-top:hover:before {
    color: #fff;
}
.bg-fixed{
	background-attachment: fixed;
    background-position: 50% 0 !important;
}
/* ================================================== */
/* R E S P O N S I V E */
/* ================================================== */
    @media only screen and (max-width: 1199px){
        .bg-fixed {background-attachment: scroll ;}
    }
    @media(min-width:980px) and (max-width: 1199px) {
        header #mainmenu a{
            padding-left:5px;
            padding-right:5px;
        }        
        #mainmenu li a:after{
            margin-left:15px;
        }
		.pf_full_width.pf_6_cols .item,
        .pf_full_width.pf_6_cols .item-grid-sizer {
			width: 25%;
		}
		.bg-fixed {
			background-repeat: no-repeat;
            background-color: #18191b;
            position: relative;
            width: 100%;     
        }
    }
    
    /* -------------------------------------------------- 
    design for 768px
    /* ================================================== */
    @media (min-width: 768px) and (max-width: 979px) {
        .slider_text {padding-top: 0px;}
        .pf_full_width .item,
        .pf_full_width.pf_4_cols .item,
        .pf_full_width.pf_6_cols .item,
        .pf_full_width.pf_5_cols .item,
        .pf_full_width.pf_3_cols .item,
        .pf_full_width .item-grid-sizer,
        .pf_full_width.pf_4_cols .item-grid-sizer,
        .pf_full_width.pf_6_cols .item-grid-sizer,
        .pf_full_width.pf_5_cols .item-grid-sizer,
        .pf_full_width.pf_3_cols .item-grid-sizer
        {
            width:33.3333333333%;
        }
    }

    @media only screen and (min-width: 993px) {
        header.header-desktop-nosticky:not(.header-bottom){position: static;}
        header.de_header_2.header-desktop-nosticky.smaller:not(.header-bottom) .info {
            position: relative;
            opacity: 1;
            z-index: 1;
        }
        header.de_header_2.header-desktop-nosticky:not(.header-bottom){height: 125px;}
        header.header-desktop-nosticky.smaller:not(.header-bottom) #mainmenu > li > a {
            padding: 25px 0 20px 20px;
        }
    }    

    @media only screen and (max-width: 992px) { 
        #menu-btn{
            display:block;
            position:relative;
            float:right;
        }                
        header{
            display:none;
        }

        header .info{
            display:none ;
        }
        
        header.header-bg{
            background:rgba(0,0,0,1);
        }

        header.de_header_2{height: auto;}       
        header.transparent{background:#000000;}
        header, header.fixed {
            display:block;
            position:inherit;
            margin:0;
            padding:0;
            margin-top:0;
            height:auto ;
            background:#000000;
            padding:15px 0 15px 0;
        }
        header div#logo{
            height: 50px;
            line-height: 50px;
        }
        header.fixed div#logo {
            height: 60px;
            line-height: 60px;
            float: left;
        }
        header div#logo a img {
            max-height: 60px;
        }        
        header.fixed div#logo img{
            height:auto;
        }
                
        header div#logo .logo-scroll {display: none;}

        #subheader{
            padding:0;
            margin:0;
        }
        .has-topbar #subheader{padding-top: 0px;}
        #subheader h1{
            margin:45px 0 45px 0;
        }
        .header-mobile-sticky-subheader #subheader{padding-top: 80px;}
        #subheader .crumb{
            display:none;
        }
        .no-subpage {display: none;}
        .slider_text h1 {
            font-size: 32px;
        }
        
        .slider_text .description {
            display: none;
        }

        .box-one-third {
            width: 100%;
        }
        .box-four-columns, 
        .box-five-columns, 
        .box-six-columns, 
        .box-two-columns {
            width: 100%;
        }
        
        .container-4 .de-team-list, .container-5 .de-team-list, .container-3 .de-team-list{
            width:49.9%;
            float:left;
            position:relative;
        }        
        .pf_full_width.pf_5_cols .item{
			width:25%;
		}
		.pf_full_width.pf_6_cols .item{
			width: 25%;
		}
		.pricing-box {
			width: 100%!important;
			float: none;
			max-width: 500px;
			margin: 0 auto 20px;
		}
        #testimonial-full blockquote {
            padding: 20px;
        }               
        nav{width:100%;}        
        #mainmenu{
            display:none;
            float:none;
            z-index:200;
            width:100%;
            margin:0;
            padding:0;
        }        
        #mainmenu ul{
            float: none;
            display: none;
            visibility: visible;
            opacity: 1;
        }
        #mainmenu a, header.header-bottom #mainmenu > li > a{
            text-align:left;
            padding-top:10px ;
            padding-bottom:10px ;
        }
        
        #mainmenu a:hover{
            background:#111 ;
        }
        
        #mainmenu > li > ul{
            visibility: visible;
            opacity: 1;
            position:inherit;
            margin:0;
            width:100%;
        }
        #mainmenu ul ul{
            visibility: visible;
            opacity: 1;
            position:static;
            width: 100%;
            left: 0%;
            height: auto;
        }
        #mainmenu li{
            border-bottom:solid 1px #333;
            margin:0;
            width:100%;
            display:block;
            letter-spacing:3px;
        }
        
        #mainmenu li a:after{
            display:none;
        }
        
        #mainmenu li:last-child{
            margin-bottom:30px;
        }
        
        #mainmenu li ul{
            border-top:solid 0px #333;
            top:auto;
        }
        
        #mainmenu li ul a{
            width:100%;
            background:none;
            border:none;
        }
        
        #mainmenu li ul li{
            border:none;
            padding-left: 40px ;
        }
        
        #mainmenu li ul li a{
            display:block;
            border-left:solid 1px #333;
            border-bottom:solid 1px #333;
        }
        
        #mainmenu li ul li:last-child{
            border-bottom:none;
            margin:0;
        }

        #mainmenu li ul li:last-child a{
            border-bottom:none;
        }
        #mainmenu li a{
            color:#eceff3;
        }
        
        #mainmenu  li li a{
            font-size:10px;
        }
        
        #mainmenu  li li a:hover{
            color:#fff;
        }
        #mainmenu li li li a {background: transparent;}
		#mainmenu li ul ul {left: 0;}        
		
		header.header-mobile-sticky{
            position:fixed;
        }
		header.header-mobile-sticky.autoshow.scrollOff{
			top: 0px;
		}
		
		header #mainmenu li ul li:first-child{
		  border-top:solid 1px #333;
		}

        header #mainmenu li ul ul li:first-child{
            border-top:solid 0px #333;
        }

        header #mainmenu li ul ul li:last-child{
            border-bottom: solid 0px #333;
        }

        header #mainmenu li ul ul{
            border-top: solid 1px #333;
        }
		
		header #mainmenu > li > ul, 
		header #mainmenu > li > ul > li ul{
			overflow:hidden;
			position:static;
            transition: all 100ms ease;
		}
		
		header #mainmenu li span{
			width:36px;
			height:36px;
			background:url(images/ui/arrow-down.png) center no-repeat;
			position:absolute;
			right:0px;
			top:0px;
			margin-top:10px;
			z-index:1000;
			cursor:pointer;
		}
		
		/* remove arrow for Polylang plugin */
		header #mainmenu li.lang-item span {background:transparent;}
		
		header #mainmenu li span.active{
			background:url(images/ui/arrow-up.png) center no-repeat;
		}

        header #mainmenu li li span{
            margin-top: 2px;
        }
		
		.smaller.header-bottom div#logo, .header-bottom div#logo {
			height: 100%;
			line-height: 60px;
			max-height: 80px;
		}		
		header #mainmenu li a span {
            width: 100%;
            height: auto;
            background: transparent;
            position: static;
            margin-top: 0px;
        }
		
        .container .col-md-3{ margin-bottom:0px;min-height: 0; }
        .container .col-md-4{ margin-bottom:30px; }
        .container .col-md-5{ margin-bottom:30px; }
        .container .col-md-6{ margin-bottom:30px; }
        .container .col-md-7{ margin-bottom:30px; }
        .container .col-md-8{ margin-bottom:30px; }
        .container .col-md-9{ margin-bottom:30px; }
        .container .col-md-10{ margin-bottom:30px; }
        .container .col-md-11{ margin-bottom:30px; }
        .container .col-md-12{ margin-bottom:30px; }
				
		.image-container, .side-bg .image-container{ 
			position:relative; 
			width:100%; 
			height:400px !important; 
            margin-bottom: 60px ;
			top:0;
		}		
		.de_tab.tab_steps  .de_nav{
			text-align:center;
		}
		
		.de_tab.tab_steps .de_nav li{
			display:block;
			margin:0;
			padding:0;
		}		
		.de_tab.tab_steps .de_nav li span{
			margin:0;
			margin-bottom:40px;
			display:inline-block;
		}		
        .de_tab.tab_steps .de_nav.process-circle-textimage .content-mid, 
		.de_tab.tab_steps .de_nav.process-circle-textonly .content-mid, 
        .de_tab.tab_steps .de_nav.process-circle-icon li span, 
        .de_tab.tab_steps .de_nav.process-circle-texticon li span {
			margin: 0px auto;
		}
        .de_tab.tab_steps .de_nav.process-circle-icon li span{
            display: block;
            vertical-align: middle;
            line-height: 150px;
        }
		.de_tab.tab_steps .de_nav li .v-border{
			border:none;
		}
		
		.mobile-hide{
			display:none;
		}
		
        .hidden-phone{
            display:none;
        }
		
		.display-table{
			display:block;
		}
		
		.display-table [class*="col-"] {
			float: none;
			display: block;
			vertical-align: top;
		}
		
        .grid_gallery .item{
            width:100%;
        }
		.services-masonry .item {margin-bottom: 30px ;}
        .footer-2 {text-align:center;}
        .footer-2 .logo-small {margin-bottom:30px;}
        .footer-2 .social-icons {
            display: inline-block;
            width: 100%;
            text-align: center;
        }
		.sm-hide{
			display:none;
		}
		
		.mt-sm-0{
			margin-top:0;
		}
        #sidebar {
            padding-left: 0px;
        }
        .leave-reply.form{margin-bottom: 100px;}
    }

    @media only screen and (max-width: 1200px) and (min-width: 768px) { 
        .de_tab.tab_steps.tab_4 .de_nav li span {          
            height: 170px;
            line-height: 115px;          
            width: 170px;
        }
    }    
    
    /* -------------------------------------------------- 
    design for 480px
    /* -------------------------------------------------- */
    @media only screen and (min-width: 480px) and (max-width: 767px) {
        .container{padding-left:30px; padding-right:30px;}
        .feature-box-image,.pricing-box{margin-bottom:30px;}
        .pf_full_width .item,
        .pf_full_width.pf_4_cols .item,
        .pf_full_width.pf_6_cols .item,
        .pf_full_width.pf_5_cols .item,
        .pf_full_width.pf_3_cols .item,
        .pf_full_width .item-grid-sizer,
        .pf_full_width.pf_4_cols .item-grid-sizer,
        .pf_full_width.pf_6_cols .item-grid-sizer,
        .pf_full_width.pf_5_cols .item-grid-sizer,
        .pf_full_width.pf_3_cols .item-grid-sizer
        {
            width:50%;
        }
    
    }    
    
    /* -------------------------------------------------- 
    design for 767px
    /* -------------------------------------------------- */
    @media only screen and (max-width: 767px) {
		body{overflow-x: hidden;}
		.subfooter .text-right, .subfooter {text-align: center;}
		.subfooter .social-icons {margin-top: 10px;}
        .container{padding-left:30px; padding-right:30px;}
        .feature-box-image,.pricing-box{margin-bottom:30px;}
        .post-video {height: auto;}
        .pf_full_width .item{
            float:left;
            width:49.9% ;
        }
        .text-item{
            font-size:48px;
            line-height:48px;
        }        
        .text-item i{
            font-size:36px;
        }
        .mfp-content .container {
            padding-right: 4px ;
            padding-left: 4px ;
        }     
        .mfp-content .project-info {margin-left: 0px;}
        .mfp-content .project-info h2, .mfp-content .project-info .details {margin-bottom: 20px;}

        .pricing-box {
            width: 100% ;
        }   
        
        .countdown-section {
            font-size: 12px;
        }
        ul.countdown li span {
            font-size: 36px;
        }
        ul.countdown li.seperator{
            padding: 10px;        
            line-height: 60px;
        }
        ul.countdown{
            padding-left: 0;
        }
        h1.title-2{
            font-size:16px;
            letter-spacing:10px;
            line-height:2em;
        }     		
        .dark .de_tab.tab_steps .de_nav li .v-border {
            border-left: none;
        }   
        .side-bg > .image-container.pull-right {
            float: none !important;
            margin-bottom: 0px !important;
        }
    }
    
    /* -------------------------------------------------- 
    design for 480px
    /* -------------------------------------------------- */
    @media only screen and (max-width: 480px) {
        .pf_full_width .item,
        .pf_full_width.pf_4_cols .item,
        .pf_full_width.pf_6_cols .item,
        .pf_full_width.pf_5_cols .item,
        .pf_full_width.pf_3_cols .item,
        .pf_full_width .item-grid-sizer,
        .pf_full_width.pf_4_cols .item-grid-sizer,
        .pf_full_width.pf_6_cols .item-grid-sizer,
        .pf_full_width.pf_5_cols .item-grid-sizer,
        .pf_full_width.pf_3_cols .item-grid-sizer
        {
            width:100%;
        }
        .container-4 .de-team-list, .container-5 .de-team-list, .container-3 .de-team-list{
            width:100%;
            float:left;
            position:relative;
        }
        .text-item{
            font-size:32px;
            line-height:32px;
        }
        
        .text-item i{
            font-size:24px;
        }
        ul.countdown li.seperator{
            padding: 0;        
            line-height: 80px;
        }
        ul.countdown li.seperator{
            width:0;
        }
        ul.countdown li p{
            margin-top:0;
        }
        .de_carousel .item {padding: 0px ;}        
        #filters li.pull-right {float: none ;}
        .padding50{padding:20px ;}
        .padding60{padding:20px ;}
        .de_testi blockquote{padding: 5px 15px 5px 15px;}
        .de_testi blockquote:before{display: none;}
        footer .widget {padding-bottom: 40px;}

        .blog-list .date-box{display: none;}
        .blog-list .post-text {padding-left: 0px;}
        .single-post #content {padding: 60px 0 60px 0;}
    }
    /* -------------------------------------------------- 
    design for 320px
    /* -------------------------------------------------- */
    @media (min-width: 300px) and (max-width: 979px) {    
        #mainmenu li a{ display:block; width:100%;}
        section{ 
			background-position:50% 0;
			-webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-attachment:scroll;
        }
        .team img.team-pic{max-width:300px;}
    }

/* -------------------------------------------------- 
    Version 3.3.0 Style
/* -------------------------------------------------- */

/* #Video Background
================================================== */
section.row-relative{position: relative;z-index:1;}
.section-video-container-wrapper {
  position: absolute;
  top: 0;
  bottom: 0;
  width: 100%;
  height: 100%; 
  overflow: hidden;
}
video#video_background {    
    /* Make video to at least 100% wide and tall */
    min-width: 100%; 
    min-height: 100%; 

    /* Setting width & height to auto prevents the browser from stretching or squishing the video */
    width: auto;
    height: auto;

    /* Center the video */
    position: absolute;
    top: 50%;
    left: 50%;
    -webkit-transform: translateX(-51%) translateY(-50%);
    -moz-transform: translateX(-51%) translateY(-50%);
    -ms-transform: translateX(-51%) translateY(-50%);
    -o-transform: translateX(-51%) translateY(-50%);
    transform: translateX(-51%) translateY(-50%);
    z-index: 1;    
}
.sep-background-mask{
    position:absolute;
    top:0;
    left:0;
    width:100%;
    height:100%;
    z-index:2;
    background-repeat: repeat;   
}
.sep-background-mask.html5overlay{
    background-image:url(images/dot-70.png);
}
.sep-background-mask.html5dotted{
    background-image:url(images/dotted.png);
}
section.row-relative > .container, section.row-relative > .row {position: relative;z-index: 100000;}

/* -------------------------------------------------- 
    Equal Height Visual Composer Style
/* -------------------------------------------------- */
@media only screen and (min-width: 768px) {
    .vc_row-o-equal-height .row:before, 
    .vc_row-o-equal-height .row:after {display:block;}
    .wpb_row.vc_row-flex .row {
        box-sizing: border-box;
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex;
        -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
        flex-wrap: wrap;
    }
    .wpb_row.vc_row-o-equal-height .vc_column_container {
        -webkit-box-align: stretch;
        -webkit-align-items: stretch;
        -ms-flex-align: stretch;
        align-items: stretch;
    }
    .wpb_row.vc_row-flex .vc_column_container {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex;
    }
    .wpb_row.vc_row-o-content-middle .vc_column_container .vc_column-inner {
        -webkit-box-pack: center;
        -webkit-justify-content: center;
        -ms-flex-pack: center;
        justify-content: center;
    }
    .wpb_row.vc_row-flex .vc_column_container .vc_column-inner {
        -webkit-box-flex: 1;
        -webkit-flex-grow: 1;
        -ms-flex-positive: 1;
        flex-grow: 1;
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-orient: vertical;
        -webkit-box-direction: normal;
        -webkit-flex-direction: column;
        -ms-flex-direction: column;
        flex-direction: column;
        z-index: 1;
    }
    .wpb_row.vc_row-o-content-top .vc_column_container .vc_column-inner {
        -webkit-box-pack: start;
        -webkit-justify-content: flex-start;
        -ms-flex-pack: start;
        justify-content: flex-start;
    }
    .wpb_row.vc_row-o-content-bottom .vc_column_container .vc_column-inner {
        -webkit-box-pack: end;
        -webkit-justify-content: flex-end;
        -ms-flex-pack: end;
        justify-content: flex-end;
    }    
    .vc_column_container > .vc_column-inner {
        box-sizing: border-box;        
        width: 100%;
    }
}

/* Add new css code in 24.10.16 */  
.logo-carousel ul li {text-align: center;}

.project-image-carousel .owl-controls {
    position: absolute !important;
    width: 100%;
    top: 50%;
    margin-top: -13px;
}
.project-image-carousel .owl-pagination {display: none;}

.project-image-carousel.owl-theme .owl-controls {
    position: relative;
}
.project-image-carousel.owl-theme .owl-controls .owl-page {
    display: inline-block;
    height: 3em;
    margin: 0 0.25em;
    outline: medium none;
    position: relative;
    transition: all 0.1s ease-in-out 0s;
    width: 6em;
}
.project-image-carousel.owl-theme .owl-controls .owl-page:focus {
    outline: medium none;
}
.project-image-carousel.owl-theme .owl-controls .owl-page span {
    display: none;
}
.project-image-carousel.owl-theme .owl-controls .owl-page:not(.active) {
    box-shadow: 0 0 10em 0 rgba(0, 0, 0, 0.6) inset;
}
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-prev, .project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-next {
    border-radius: 1px;
    display: block;
    font-size: 2em;
    height: 1em;
    line-height: 0.75em;
    position: absolute;
    width: 1em;
}
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-prev:focus, .project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-next:focus {
    box-shadow: 0 0 10em 0 rgba(255, 0, 0, 0.6) inset;
}
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-prev {
    left: 0em;
}
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-next {
    right: 0em;
}
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-prev:before,
.project-image-carousel.owl-theme .owl-controls .owl-buttons .owl-next:after{font-size: 20px;}
.project-image-carousel .owl-item img {
    height: auto;
    max-width: 100%;
    display: block;
}

/* OT Image Carousel */
.image__carousel-sync2.owl-carousel {margin-left: -2.5px;}
.image__carousel-sync2 {
    margin-top: 10px;
    margin-bottom: 10px;
}
.image__carousel-sync2 .owl-item {
    cursor: pointer;
    -webkit-transition: all 0.4s;
    -moz-transition: all 0.4s;
    -ms-transition: all 0.4s;
    -o-transition: all 0.4s;
    transition: all 0.4s;
    padding-left: 5px;
}
.image__carousel-sync2 .owl-item.synced {}
.image__carousel-sync2 .owl-item img {
    max-width: 100%;
    border: 4px solid #b3b2b2;
    display: block;
}
.image__carousel-sync2 .owl-item.synced img {
    border-color: #FAB207;
}
.de_tab_content_inner .vc_column_container > .vc_column-inner {
  padding-left: 0px;
  padding-right: 0px;
}
.de_tab_content_inner section{background-color: transparent;}
.share-holder {
  float: right;
  margin-bottom: 0;
  margin-left: 0;
  margin-top: 0;
}
.share-holder h4, .social-links.rounded-share-icons {
  display: inline-block;
  margin: 0px;
}
.share-holder .social-links.rounded-share-icons a {
    display: inline-block;
    margin-left: 6px;
}
.share-holder .social-links.rounded-share-icons a i {
    font-size: 15px;
    color: #fff;
    float: none;
    margin: 0px;
    -o-transition:.3s;
    -ms-transition:.3s;
    -moz-transition:.3s;
    -webkit-transition:.3s;
    transition:.3s;
}
.post-controls{padding: 40px 0px 40px;margin: 0px 0px 40px;border-bottom: 1px solid #e8eaec;border-top: 1px solid #e8eaec;}
.post-controls .nav-previous{}
.post-controls .nav-next{text-align: right;}
.post-controls a:hover {text-decoration: none;}
.post-controls .post-title em{display: block;font-style: normal;color: #f6f6f6;text-transform: uppercase;text-decoration: underline;margin-bottom: 10px;}
.post-controls .post-title strong{display: block;font-weight: 300; font-size: 15px;color: #f2f2f2;}
.post-controls .nav-previous .post-title{}
.post-controls .nav-next .post-title{}
.text-slider .text-item b{font-weight: normal;}
.nav-links:before{
    display: table;
    content: " ";
}
.nav-links:after{
    display: table;
    content: " ";
    clear: both;
}

/* Revolution Slider Setting */
html {
    overflow-x:hidden;
    padding: 0 !important;
    background:#fff;
    margin:0px !important;
}
#revolution-slider{
    font-family: 'Raleway', sans-serif;
    font-weight: 400;
}
.tp-caption{
    font-size:14px;
    font-weight:300;
}
.tp-caption.teaser{
letter-spacing:5px;
}
.tp-caption br{
margin-bottom:5px;
}
.tparrows{ top:50% !important;}
.med{
    font-size:24px;
    letter-spacing:-.5px;
}
.med-white{
    color:#fff;
    font-size:24px;
    letter-spacing:-.5px;
}
.med-green{
    color:#1a8b49;
    font-size:24px;
    letter-spacing:-.5px;
}
.small-white{
    color:#fff;
    line-height:1.7em;
}
.big-black{
    font-size:52px;
    letter-spacing:-3px;
    color:#222;
}
.big-white{
    font-size:16px;
    color:#fff;
    line-height:normal;
    font-weight:300;
    text-transform:uppercase;
    letter-spacing:6px;
}
.ultra-big-white, .big-text h2{
    font-size:72px;
    font-weight:300;
    letter-spacing:10px;
    color:#fff;
    margin:0;
    text-transform:uppercase;
}
.ultra-big-black{
    font-size:96px;
    font-weight:400;
    color:#222;
    margin:0;
    line-height:72px;
}

a.btn-slider{
    color:#fff;
}

a.btn-slider:hover{
    color:#222;
}

.fullwidthbanner-container a.btn{
    text-transform:uppercase;
    letter-spacing:1px;
    color:#fff !important;
    font-weight:700;
    padding:10px 20px 10px 20px;
    border-radius:0;
    -moz-border-radius:0;
    -webkit-border-radius:0;
}

.tp-caption.separator {
    width:100px;
    border-bottom:solid 1px rgba(255,255,255,.3);
}
.tparrows.tp-rightarrow:before, .tparrows.tp-leftarrow:before{content: '';}
.tp-leftarrow, .tp-leftarrow:hover  {background:url(images/large_left.png) no-Repeat top left !important;position: absolute;}
.tp-rightarrow, .tp-rightarrow:hover {background:url(images/large_right.png) no-Repeat top left !important;position: absolute;}

@media only screen and (max-width: 480px) {
    .big-white, .big-text {margin-left:20px; }
}

/* Magnific Popup CSS */
.mfp-bg {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 10000000;
  overflow: hidden;
  position: fixed;
  background: #0b0b0b;
  opacity: 0.9;
  filter: alpha(opacity=90); }

.de_light .mfp-bg {
  background: #fff;
  opacity: .95;
  filter: alpha(opacity=95);
}
  
.mfp-wrap {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 10000000;
  position: fixed;
  outline: none !important;
  -webkit-backface-visibility: hidden; 
  -webkit-overflow-scrolling: touch;
  -webkit-transform: translateZ(0);
}
html.mfp-helper {
    height: 100%;    
}
.mfp-container {
  text-align: center;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  padding: 0 8px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box; 
}
.mfp-container:before {
  content: '';
  display: inline-block;
  height: 100%;
  vertical-align: middle; 
}

.mfp-align-top .mfp-container:before {display: none; }

.mfp-content {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin: 0 auto;
  text-align: left;
  z-index: 1045; 
}

.mfp-inline-holder .mfp-content, .mfp-ajax-holder .mfp-content {
  width: 100%;
  cursor: auto; 
}

.mfp-ajax-cur {cursor: progress; }

.mfp-zoom-out-cur, .mfp-zoom-out-cur .mfp-image-holder .mfp-close {
  cursor: -moz-zoom-out;
  cursor: -webkit-zoom-out;
  cursor: zoom-out;
}

.mfp-zoom {
  cursor: pointer;
  cursor: -webkit-zoom-in;
  cursor: -moz-zoom-in;
  cursor: zoom-in; 
}

.mfp-auto-cursor .mfp-content {cursor: auto; }

.mfp-close, .mfp-arrow, .mfp-preloader, .mfp-counter {
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none; 
}

.mfp-loading.mfp-figure {display: none; }

.mfp-hide {display: none !important; }

.mfp-preloader {
  color: #CCC;
  position: absolute;
  top: 50%;
  width: auto;
  text-align: center;
  margin-top: -0.8em;
  left: 8px;
  right: 8px;
  z-index: 1044; 
}
.mfp-preloader a {color: #CCC; }
.mfp-preloader a:hover {color: #FFF; }
.mfp-s-ready .mfp-preloader {display: none; }
.mfp-s-error .mfp-content {display: none; }

button.mfp-close, button.mfp-arrow {
  overflow: visible;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
  display: block;
  outline: none;
  padding: 0;
  z-index: 1046;
  -webkit-box-shadow: none;
  box-shadow: none; 
}
button::-moz-focus-inner {
  padding: 0;
  border: 0;
}

.mfp-close {
  width: 44px;
  height: 44px;
  line-height: 44px;
  position: absolute;
  right: 0;
  top: 0;
  text-decoration: none;
  text-align: center;
  opacity: 0.65;
  filter: alpha(opacity=65);
  padding: 0 0 18px 10px;
  color: #FFF;
  font-style: normal;
  font-size: 28px;
  font-family: Arial, Baskerville, monospace; 
}
.mfp-close:hover, .mfp-close:focus {
    opacity: 1;
    filter: alpha(opacity=100); 
}
.mfp-close:active {top: 1px; }

.mfp-close-btn-in .mfp-close {
  color: #333;
}

.mfp-image-holder .mfp-close, .mfp-iframe-holder .mfp-close {
  color: #fff;
  left: 0;
  padding-right: 0;
  right: 0;
  text-align: center;
  top: -100px !important;
  width: 100%;
}

.mfp-counter {
  position: absolute;
  top: 0;
  right: 0;
  color: #CCC;
  font-size: 12px;
  line-height: 18px;
  white-space: nowrap; }

.mfp-arrow {
  position: absolute;
  opacity: 0.65;
  filter: alpha(opacity=65);
  margin: 0;
  top: 50%;
  margin-top: -55px;
  padding: 0;
  width: 90px;
  height: 110px;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0); 
}
.mfp-arrow:active {margin-top: -54px; }
.mfp-arrow:hover, .mfp-arrow:focus {
    opacity: 1;
    filter: alpha(opacity=100); 
}
.mfp-arrow:before, .mfp-arrow:after, .mfp-arrow .mfp-b, .mfp-arrow .mfp-a {
    content: '';
    display: block;
    width: 0;
    height: 0;
    position: absolute;
    left: 0;
    top: 0;
    margin-top: 35px;
    margin-left: 35px;
    border: medium inset transparent; 
}
.mfp-arrow:after, .mfp-arrow .mfp-a {
    border-top-width: 13px;
    border-bottom-width: 13px;
    top: 8px; 
}
.mfp-arrow:before, .mfp-arrow .mfp-b {
    border-top-width: 21px;
    border-bottom-width: 21px;
    opacity: 0.7;
}

.mfp-arrow-left {left: 0; }
.mfp-arrow-left:after, .mfp-arrow-left .mfp-a {
    border-right: 17px solid #FFF;
    margin-left: 31px; 
}
.mfp-arrow-left:before, .mfp-arrow-left .mfp-b {
    margin-left: 25px;
    border-right: 27px solid #3F3F3F; 
}

.mfp-arrow-right {right: 0; }
.mfp-arrow-right:after, .mfp-arrow-right .mfp-a {
    border-left: 17px solid #FFF;
    margin-left: 39px; 
}
.mfp-arrow-right:before, .mfp-arrow-right .mfp-b {border-left: 27px solid #3F3F3F; }

.mfp-iframe-holder {
  padding-top: 40px;
  padding-bottom: 40px; 
}
.mfp-iframe-holder .mfp-content {
    line-height: 0;
    width: 100%;
    max-width: 900px; 
}
.mfp-iframe-holder .mfp-close {top: -40px; }

.mfp-iframe-scaler {
  width: 100%;
  height: 0;
  overflow: hidden;
  padding-top: 56.25%; }
  .mfp-iframe-scaler iframe {
    position: absolute;
    display: block;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #000; 
}

/* Main image in popup */
img.mfp-img {
  width: auto;
  max-width: 100%;
  height: auto;
  display: block;
  line-height: 0;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 40px 0 40px;
  margin: 0 auto; 
}

/* The shadow behind the image */
.mfp-figure {line-height: 0; }
.mfp-figure:after {
    content: '';
    position: absolute;
    left: 0;
    top: 40px;
    bottom: 40px;
    display: block;
    right: 0;
    width: auto;
    height: auto;
    z-index: -1;
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #444; 
}
  .mfp-figure small {
    color: #BDBDBD;
    display: block;
    font-size: 12px;
    line-height: 14px; 
}
.mfp-figure figure {margin: 0; }

.mfp-bottom-bar {
  margin-top: -36px;
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  cursor: auto; 
}

.mfp-title {
  text-align: left;
  line-height: 18px;
  color: #F3F3F3;
  word-wrap: break-word;
  padding-right: 36px; 
}

.mfp-image-holder .mfp-content {max-width: 100%; }

.mfp-gallery .mfp-image-holder .mfp-figure {cursor: pointer; }

@media screen and (max-width: 800px) and (orientation: landscape), screen and (max-height: 300px) {
  /**
       * Remove all paddings around the image on small screen
       */
    .mfp-img-mobile .mfp-image-holder {
        padding-left: 0;
        padding-right: 0; 
    }
    .mfp-img-mobile img.mfp-img {padding: 0; }
    .mfp-img-mobile .mfp-figure:after {
        top: 0;
        bottom: 0; 
    }
    .mfp-img-mobile .mfp-figure small {
        display: inline;
        margin-left: 5px; 
    }
    .mfp-img-mobile .mfp-bottom-bar {
        background: rgba(0, 0, 0, 0.6);
        bottom: 0;
        margin: 0;
        top: auto;
        padding: 3px 5px;
        position: fixed;
        -webkit-box-sizing: border-box;
        -moz-box-sizing: border-box;
        box-sizing: border-box; 
    }
    .mfp-img-mobile .mfp-bottom-bar:empty {padding: 0; }
    .mfp-img-mobile .mfp-counter {
        right: 5px;
        top: 3px; 
    }
    .mfp-img-mobile .mfp-close {
        top: 0;
        right: 0;
        width: 35px;
        height: 35px;
        line-height: 35px;
        background: rgba(0, 0, 0, 0.6);
        position: fixed;
        text-align: center;
        padding: 0; 
    }
 }

@media all and (max-width: 900px) {
    .mfp-arrow {
        -webkit-transform: scale(0.75);
        transform: scale(0.75); 
    }

    .mfp-arrow-left {
        -webkit-transform-origin: 0;
        transform-origin: 0; 
    }

    .mfp-arrow-right {
        -webkit-transform-origin: 100%;
        transform-origin: 100%; 
    }

    .mfp-container {
        padding-left: 6px;
        padding-right: 6px; 
    }
}

.mfp-ie7 .mfp-img {padding: 0; }
.mfp-ie7 .mfp-bottom-bar {
  width: 600px;
  left: 50%;
  margin-left: -300px;
  margin-top: 5px;
  padding-bottom: 5px; 
}
.mfp-ie7 .mfp-container {padding: 0; }
.mfp-ie7 .mfp-content {padding-top: 44px; }
.mfp-ie7 .mfp-close {
  top: 0;
  right: 0;
  padding-top: 0; 
}


/* section background
/* -------------------------------------------------- */
section, #subheader{
    -webkit-background-size: 100% !important;
    -moz-background-size: 100% !important;
    -o-background-size: 100% !important;
    background-size: 100% !important;
}
#subheader{background-position: top;background-attachment: fixed;}
#view-all-projects, #call-to-action{padding:60px 0 60px 0;}
#section-about-us-2{background:#f8f8f8; height:100%;}
#section-coming-soon{ background:none; position:absolute; min-height:100%; width:100%;z-index:1;}
#bg-coming-soon-page{background-position: top; background-attachment: fixed; position:fixed; min-height:100%; width:100%;}
#section-about-us-2{background:#18191b; height:100%;}
#section-portfolio{background:#222; width:101%;}
#section-team{background:#111;}
#hide-content{position:absolute; width:100%; min-height:100%; z-index:100;display:none; background:rgba(0,0,0,.8);}

.vc_cta3-content-header{position:static;height: auto;}
.vc_cta3-container {margin-bottom: 0px;}
header.autoshow .info{display: none;}
.header-bottom .info {display: none;}
.services-masonry-item-mb0 .services-masonry .item {margin-bottom: 0px;}

@media only screen and (max-width: 992px) {
    section,#subheader{
        -webkit-background-size:cover !important;
        -moz-background-size: cover !important;
        -o-background-size: cover !important;
        background-size: cover !important;
    }
    .services-masonry-item-mb0 .services-masonry .item {margin-bottom: 60px;}
    .services-masonry-item-mb0 .services-masonry .item:last-child{margin-bottom: 0px;}
}

@media only screen and (max-width: 767px) {
    #subheader {background-attachment: scroll;}
}

@media only screen and (max-width: 480px) {
    .single-comment li{padding-bottom: 0px;}
    .avatar {width: 30px;height: auto;}
    .comment-content, .post-content-comment .date, .comment-content{margin-left: 40px;}
    .single-comment .children{margin-left: 40px;padding: 0px;}
    .share-holder{float: none;margin-top: 20px;}
    .post-info {margin: 20px 0 0;padding-bottom: 10px;}
    #subheader .title-wrap {float: none;}
    #subheader h1{padding: 0px;font-size: 22px;text-align: center;}
    .grid-item .pf_title{display:none;}
    h1.title-3{font-size:42px;}
}
.gm-style .gm-style-iw {
    font-size: 14px;
    font-weight: 300;
    color: #333;
}
.gm-style .gm-style-iw h3{
    color: #333;
    margin-bottom: 10px;
    margin-top: 20px;
}
ul.sidebar-style-2 {
  display: block;
  width: 100%;
  margin: 0px;
  padding: 0px;
}
ul.sidebar-style-2 li {
  display: block;
  width: 100%;
  background: #f2f2f2;
  transition: all 0.4s;
  margin-bottom: 5px;
  border-left: 4px solid #f2f2f2;
}
ul.sidebar-style-2 li a {
  color: #555555;
  font-size: 15px;
  display: block;
  width: 100%;
  line-height: 50px;
  padding: 0 15px;
  transition: all 0.4s;
  text-decoration: none;
}
ul.sidebar-style-2 li:hover {
  border-left: 4px solid #fab207;
  background: #000;
}
ul.sidebar-style-2 li:hover a {
  color: #fab207;
}
ul.sidebar-style-2 li.active {
  border-left: 4px solid #fab207;
  background: #000;
}
ul.sidebar-style-2 li.active a {
  color: #fab207;
}

/* .projects-grid
================================================== */
.projects-grid {
  position: relative;
}
.projects-grid:after {
  content: "";
  display: block;
  clear: both;
}
.projects-grid.row .project-item {margin-bottom: 30px;}
.project-item {
  float: left;
  display: inline-block;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.projects-grid.pf_3_cols .project-item,
.projects-grid.pf_3_cols .project-item-sizer {
  width: 33.3333333333%;
}
.projects-grid.pf_3_cols .project-item.large-width {
  width: 66.6666666666%;
}

.projects-grid.pf_6_cols .project-item, 
.projects-grid.pf_6_cols .project-item-sizer {
  width: 16.666666666666664%;
}
.projects-grid.pf_6_cols .project-item.large-width {
  width: 33.33333333333333%;
}

.projects-grid.pf_5_cols .project-item,
.projects-grid.pf_5_cols .project-item-sizer {
  width: 20%;
}
.projects-grid.pf_5_cols .project-item.large-width {
  width: 40%;
}
.projects-grid.pf_4_cols .project-item, 
.projects-grid.pf_4_cols .project-item-sizer {
  width: 25%;
}
.projects-grid.pf_4_cols .project-item.large-width {
  width: 50%;
}
.projects-grid.pf_2_cols .project-item,
.projects-grid.pf_2_cols .project-item-sizer {
  width: 50%;
}
.projects-grid.pf_2_cols .project-item.large-width {
  width: 100%;
}
.projects-box {
  position: relative;
  display: block;
  overflow: hidden;
}
.projects-box .projects-thumbnail {
  position: relative;
  overflow: hidden;
  z-index: 2;
}
.projects-box .projects-thumbnail img {
  -o-transition: 1s;
  -ms-transition: 1s;
  -moz-transition: 1s;
  -webkit-transition: 1s;
  transition: 1s;
  outline: none;
  max-width: 100%;
}
.large-width .projects-box .projects-thumbnail img,
.large-height .projects-box .projects-thumbnail img {
    width: 100%;
}
.projects-box .project-overlay {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  display: flex;
  flex-wrap: wrap;
  justify-content: center;
  align-items: center;
  z-index: 3;
  -o-transition: 0.5s;
  -ms-transition: 0.5s;
  -moz-transition: 0.5s;
  -webkit-transition: 0.5s;
  transition: 0.5s;
}
.projects-box .project-overlay .project-name {
  font-size: 11px;
  text-transform: uppercase;
  letter-spacing: 5px;
  font-weight: bold;
  display: block;
  -o-transition: 0.3s;
  -ms-transition: 0.3s;
  -moz-transition: 0.3s;
  -webkit-transition: 0.3s;
  transition: 0.3s;
}
.projects-box:hover img {
  transform: scale(1.3);
}

.overlay_s1 .projects-box .project-overlay {
  background: #111;
  /* The Fallback */
  background: rgba(17, 17, 17, 0.9);
  visibility: hidden;
  opacity: 0;
}
.overlay_s1 .projects-box .project-overlay .project-name {
  -webkit-transform: translateY(30px);
  -ms-transform: translateY(30px);
  transform: translateY(30px);
}
.overlay_s1 .projects-box:hover .project-overlay {
  visibility: visible;
  opacity: 1;
}
.overlay_s1 .projects-box:hover .project-overlay .project-name {
  -webkit-transform: translateY(0px);
  -ms-transform: translateY(0px);
  transform: translateY(0px);
}

.overlay_s2 .projects-box .project-overlay {
  background: #000;
  /* The Fallback */
  background: rgba(0, 0, 0, 0.7);
  align-items: baseline;
}
.overlay_s2 .projects-box .project-overlay .project-name {
  -o-transition: 0.5s;
  -ms-transition: 0.5s;
  -moz-transition: 0.5s;
  -webkit-transition: 0.5s;
  transition: 0.5s;
  position: absolute;
  bottom: 10%;
}
.overlay_s2 .projects-box:hover .project-overlay {
  background: #000;
  /* The Fallback */
  background: rgba(0, 0, 0, 0);
}
.overlay_s2 .projects-box:hover .project-overlay .project-name {
  bottom: -20%;
  opacity: 0;
}

.overlay_s3 .projects-box .project-overlay {
  background: #000;
  background: rgba(0, 0, 0, 0.7);
}
.overlay_s3 .projects-box:hover .project-overlay {
  background: #000;
  background: rgba(0, 0, 0, 0);
}
.overlay_s3 .projects-box:hover .project-overlay .project-name {
  transform: scale(1.2);
  opacity: 0;
}

.overlay_s4 .projects-box .project-overlay {
  background: #282828;
  background: rgba(40, 40, 40, 0.3);
}
.overlay_s4 .projects-box .project-overlay .project-name {
  font-size: 16px;
  letter-spacing: 0;
  text-transform: none;
  color: #fff;
}
.overlay_s4 .projects-box:hover .project-overlay {
  background: #000;
  background: rgba(0, 0, 0, 0);
}
.overlay_s4 .projects-box:hover .project-overlay .project-name {
  transform: scale(1.2);
  opacity: 0;
}

/**** Isotope Filtering ****/
.project-filter-wrapper .container {
  padding: 0;
}
.project_filters {
  position: relative;
  width: 100%;
  text-align: center;
  margin-top: 30px;
  margin-bottom: 20px;
  padding-left: 0;
}
.project_filters:after {
  content: "";
  display: block;
  clear: both;
}
.project_filters.s2 {
  text-align: left;
}
.project_filters.s2 li:first-child {
  float: right;
  margin-right: 0px;
}
.project_filters li {
  display: inline-block;
  text-align: center;
  margin-right: 5px;
  margin-bottom: 10px;
}
.project_filters li:first-child {
  margin-left: 0px;
}
.project_filters li:last-child {
  margin-right: 0px;
}
.project_filters li a {
  position: relative;
  color: #888;
  font-size: 11px;
  letter-spacing: 3px;
  font-weight: 400;
  line-height: 1.8em;
  text-align: center;
  outline: none;
  padding: 8px 20px 8px 20px;
  text-decoration: none;
  display: inline-block;
  text-transform: uppercase;
  transition: all 0.3s linear;
  -webkit-transition: all 0.3s linear;
  -moz-transition: all 0.3s linear;
  -o-transition: all 0.3s linear;
  -ms-transition: all 0.3s linear;
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}
.project_filters li a:hover {
  background: #111;
}
.project_filters li a.selected {
  color: #111;
  background-color: #fab702;
}

/* Start: Recommended Isotope styles */
/**** Isotope Filtering ****/
.isotope-item {
  z-index: 2;
}

.isotope-hidden.isotope-item {
  pointer-events: none;
  z-index: 1;
}

/**** Isotope CSS3 transitions ****/
.isotope,
.isotope .isotope-item {
  -webkit-transition-duration: 0.6s;
  -moz-transition-duration: 0.6s;
  -ms-transition-duration: 0.6s;
  -o-transition-duration: 0.6s;
  transition-duration: 0.6s;
}

.isotope {
  -webkit-transition-property: height, width;
  -moz-transition-property: height, width;
  -ms-transition-property: height, width;
  -o-transition-property: height, width;
  transition-property: height, width;
}

.isotope .isotope-item {
  -webkit-transition-property: -webkit-transform, opacity;
  -moz-transition-property: -moz-transform, opacity;
  -ms-transition-property: -ms-transform, opacity;
  -o-transition-property: -o-transform, opacity;
  transition-property: transform, opacity;
}

/**** disabling Isotope CSS3 transitions ****/
.isotope.no-transition,
.isotope.no-transition .isotope-item,
.isotope .isotope-item.no-transition {
  -webkit-transition-duration: 0s;
  -moz-transition-duration: 0s;
  -ms-transition-duration: 0s;
  -o-transition-duration: 0s;
  transition-duration: 0s;
}

/* End: Recommended Isotope styles */
@media only screen and (max-width: 1199px) {
    .projects-grid.pf_5_cols .project-item-sizer,
    .projects-grid.pf_5_cols .project-item,
    .projects-grid.pf_6_cols .project-item, 
    .projects-grid.pf_6_cols .project-item-sizer {
        width: 25%;
    }
}
@media only screen and (max-width: 993px) {
    .project-item, .project-item.large-width,
    .projects-grid .project-item-sizer,
    .projects-grid.pf_6_cols .project-item, 
    .projects-grid.pf_6_cols .project-item-sizer,
    .projects-grid.pf_5_cols .project-item-sizer,
    .projects-grid.pf_4_cols .project-item-sizer,
    .projects-grid.pf_4_cols .project-item,
    .projects-grid.pf_5_cols .project-item {
        width: 50%;
    }
}
@media only screen and (max-width: 600px) {
    .project-item, .project-item.large-width,
    .projects-grid .project-item-sizer,
    .projects-grid.pf_6_cols .project-item, 
    .projects-grid.pf_6_cols .project-item-sizer,
    .projects-grid.pf_5_cols .project-item-sizer,
    .projects-grid.pf_4_cols .project-item-sizer,
    .projects-grid.pf_2_cols .project-item-sizer,
    .projects-grid.pf_5_cols .project-item,
    .projects-grid.pf_4_cols .project-item,
    .projects-grid.pf_2_cols .project-item {
        width: 100%;
    }
}
.addtoany_share_save_container {max-width: 1170px;margin: 16px auto !important;}

/* OT Simple Process
================================================== */
.process-carousel-wrap{ 
    position:relative;
    width:100%;
    margin:0 auto;
    overflow:hidden;
    z-index:2;
} 
.process-sync1{
    position: relative;
    max-width:800px;
    margin: 0 auto;
    width:100%;
}
.process-sync1 .item {
    display: block;
    color: #eceff3;
}
.process-sync1 .item:after {
  content: '';
  display: block;
  clear: both;
}
.process-sync2 {
    position:relative;
    width:100%;
    max-width:550px;
    margin:0 auto;
}
.process-sync2 .item{
    width:80%;
    margin-left:10%;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    z-index:200;
    cursor:pointer;
    margin-top:80px;
    -webkit-transition: all 300ms linear;
    -moz-transition: all 300ms linear;
    -o-transition: all 300ms linear;
    -ms-transition: all 300ms linear;
    transition: all 300ms linear;
    text-align: center;
}
.process-sync2 .item .line{
    position:absolute;
    width:100%;
    height:1px;
    top:80px;
    left:-100%;
    z-index:1px;
    background:#eceff3;
    opacity:0;
    -webkit-transition: -webkit-transform 0.3s;
    transition: transform 0.3s;
}
.process-sync2 .item .point-item {
    position: absolute;
    border-radius: 50%;
    width: 7px;
    height: 7px;
    background:#eceff3;
    z-index:1;
    top:40px;
    left:50%;
    margin-left:-3px;
    opacity:0;
    -webkit-transition: -webkit-transform 0.6s;
    transition: transform 0.6s;
}
.process-sync2 .item .line-ver{
    position:absolute;
    width:1px;
    height:20px;
    top:40px;
    left:50%;
    z-index:1px;
    background:#eceff3;
    opacity:0;
    -webkit-transition: -webkit-transform 0.4s;
    transition: transform 0.4s;
}
.process-sync2 .item p{
    font-family: 'Open Sans', sans-serif;
    font-weight:600;
    font-size: 12px;
    line-height:25px;
    padding-top:10px;
    color:#eceff3;
    text-transform: uppercase;
    letter-spacing:3px;
    -webkit-transition: all 300ms linear;
    -moz-transition: all 300ms linear;
    -o-transition: all 300ms linear;
    -ms-transition: all 300ms linear;
    transition: all 300ms linear;
}
.process-sync2 .synced .item .line{
    -webkit-transform: translate3d(100%,0,0);
    transform: translate3d(100%,0,0);
    opacity:1;
}
.process-sync2 .synced .item .line-ver{
    -webkit-transform: translate3d(0,100%,0);
    transform: translate3d(0,100%,0);
    opacity:1;
}
.process-sync2 .synced .item .point-item {
    -webkit-transform: translate3d(0,100%,0);
    transform: translate3d(0,100%,0);
    opacity:1;
}

.text-dark .process-sync1 .item{color: #606060;}
.text-dark .process-sync2 .item .line, .text-dark .process-sync2 .item .point-item,
.text-dark .process-sync2 .item .line-ver{background: #212121;}
.text-dark .process-sync2 .item p {color: #212121;}
.mfp-close.popup-exit {display:none;}
@media only screen and (max-width : 992px) {
    .mfp-close.popup-exit {
        top: auto;
        bottom: 10px;
        width: 150px;
        text-align: center;
        font-size: 18px !important;
        color: #fff !important;
        opacity: 1;
        background: #333;  
        margin-left: -75px; 
		display:block;
    }
}
.ot_custom_heading a {color: inherit;text-decoration: none;}
.ot_custom_heading a:hover{text-decoration: none;color: inherit;}
.mb-30 {margin-bottom: -30px;}

/* Archi Industry version */
.info-box i{
    font-size:40px;
    position:absolute;
}
.info-box .info-box_text{
    padding-left:60px;
}
.info-box .info-box_title{
    font-weight:700;
    text-transform:uppercase;
    line-height:16px;
    color:#fff;
    margin-top:8px;
}
#info-box{
    height:90px;
    position:absolute;
    z-index:500;
    width:100%; 
    background:rgba(0,0,0,.3);
}
@media only screen and (max-width : 767px) {
    #info-box{
        background: #fff;
        height:auto;
        position:static;
        margin-top: 0px;
    }
    .info-box .info-box_title, .info-box .info-box_text{
        color: #333;
    }
    .info-box {padding: 20px 0px;}
}
h2 .wm {
    display: block;
    color: rgba(0,0,0,.05);
    font-size: 80px;
    width: 100%;
    position: absolute;
    text-align: left;
    margin-left: -130px;
    z-index: 0;
}
h2.inline-block {display: inline-block;}
.separator.separator-bold span:before, .separator.separator-bold span:after {border-bottom-width: 2px;}
.separator.separator-bold span i {font-size: 20px;margin-top: -5px;}
section.stellar-fixed { background:top fixed;}
@media only screen and (max-width: 1199px){
    section.stellar-fixed {
        -webkit-background-size: 100% 100% !important;
        -moz-background-size: 100% 100% !important;
        -o-background-size: 100% 100% !important;
        background-size: 100% 100% !important;
        background-attachment: scroll !important;
        background-position: top !important;
    }
}
@media only screen and (max-width: 992px){
    section.stellar-fixed {
        -webkit-background-size: cover !important;
        -moz-background-size: cover !important;
        -o-background-size: cover !important;
        background-size: cover !important;
        background-position: top center !important;
    }
}
.info-details .info-text {margin-bottom: 20px;}

@media only screen and (max-width : 767px) {
    .text-slider{
        line-height:36px;       
        font-size:36px;
        letter-spacing:10px;
    }
    .text-slider.big-text{
        font-size:60px;
        line-height:60px;
    }
    h1.slogan_big {
        font-size: 32px;
        line-height: 32px;
    }
    h1.title{
        font-size:32px;
        letter-spacing:5px;
    }
    h1.title-2{
        letter-spacing:10px;
        line-height:25px;
    }
    h1.title-3{
        font-size:36px;
    }
    h1.title.s2 {
        font-size: 32px;
    }
    h2.hero {
        font-size: 32px;
        letter-spacing: 32px;                
    }   
    h2.style-3 {
        font-size:32px;
        letter-spacing:10px;
    }
    h2.style-4 {
        font-size:30px;
    }
    h2.style-5 {        
        line-height:1em;
        font-size:24px;        
    }
}


/* ---- grid ---- */

.projects-grids {
  max-width: 100%;
}

/* clearfix */
.projects-grids:after {
  content: '';
  display: block;
  clear: both;
}

/* ---- grid-item ---- */

/* fluid 4 columns */
.grid-sizers,
.grid-items { width: 25%; }
.grid-items {
  float: left;
}
/* 2 columns */
.grid-items--width2 { width: 50%; }

/* fluid 5 columns */
.grid-columns-5 .grid-items { width: 20%; }
.grid-columns-5 .grid-items--width2 { width: 40%; }

/* fluid 3 columns */
.grid-columns-3 .grid-items { width: 33.33333333333333%; }
.grid-columns-3 .grid-items--width2 { width: 66.66666666666666%; }

/* fluid 2 columns */
.grid-columns-2 .grid-items { width: 50%; }
.grid-columns-2 .grid-items--width2 { width: 100%; }

.grid-items img{max-width: 100%;}

@media only screen and (max-width : 767px) {
    .grid-sizers,
    .grid-items { width: 50%; }
}
@media only screen and (max-width : 480px) {
    .grid-sizers,
    .grid-items { width: 100%; }
}

.de_tab.tab_steps .de_nav.de_nav_links li a{
    text-decoration: none;
}
.img-rounded .twentytwenty-overlay {
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
}